@@ -160,7 +160,15 @@ public:
 	Tp * lengths(){ return mLengths; }
 	const Tp * lengths() const { return mLengths; }
 
-	/// Set break-point values
+	/// Set length of a segment (compile-time checked)
+	template <unsigned i>
+	Env& length(Tp v){
+		static_assert(i<N, "Invalid segment index");
+		lengths()[i] = v;
+		return *this;
+	}
+
+	/// Set lengths of segments
 	template <class V>
 	Env& lengths(const V* vals, int len){
 		int n = len <= size() ? len : size();
@@ -168,24 +176,18 @@ public:
 		return *this;
 	}
 
-	/// Set first two segment lengths
+	/// Set lengths of first two segments
 	Env& lengths(Tp a, Tp b){ Tp v[]={a,b}; return lengths(v,2); }
 
-	/// Set first three segment lengths
+	/// Set lengths of first three segments
 	Env& lengths(Tp a, Tp b, Tp c){ Tp v[]={a,b,c}; return lengths(v,3); }
 
-	/// Set first four segment lengths
+	/// Set lengths of first four segments
 	Env& lengths(Tp a, Tp b, Tp c, Tp d){ Tp v[]={a,b,c,d}; return lengths(v,4); }
 
-	/// Set first five segment lengths
+	/// Set lengths of first five segments
 	Env& lengths(Tp a, Tp b, Tp c, Tp d, Tp e){ Tp v[]={a,b,c,d,e}; return lengths(v,5); }
 
-	template <unsigned i>
-	Env& length(Tp v){
-		static_assert(i<N, "Invalid segment index");
-		lengths()[i] = v;
-		return *this;
-	}
 
 	/// Get total length of all envelope segments
 	Tp totalLength() const;
@@ -203,7 +205,15 @@ public:
 	/// Get segment curvature array
 	Tp * curves(){ return mCurves; }
 	const Tp * curves() const { return mCurves; }
-	
+
+	/// Set curvature of a segment (compile-time checked)
+	template <unsigned i>
+	Env& curve(Tp v){
+		static_assert(i<N, "Invalid curve index");
+		curves()[i] = v;
+		return *this;
+	}
+
 	/// Set curvature of all segments
 	Env& curve(Tp v){
 		for(int i=0; i<N; ++i) curves()[i]=v;
@@ -230,13 +240,6 @@ public:
 	Env& curves(Tp ca, Tp cb, Tp cc, Tp cd){
 		Tp c[]={ca,cb,cc,cd}; return curves(c,4); }
 
-	template <unsigned i>
-	Env& curve(Tp v){
-		static_assert(i<N, "Invalid curve index");
-		curves()[i] = v;
-		return *this;
-	}
-
 
 	/// Set length and curvature of a segment
 	Env& segment(int i, Tp len, Tp crv){
@@ -245,6 +248,7 @@ public:
 		return *this;
 	}
 
+	/// Set length and curvature of a segment (compile-time checked)
 	template <unsigned i>
 	Env& segment(Tp len, Tp crv){
 		static_assert(i<N, "Invalid segment index");
@@ -279,6 +283,14 @@ public:
 	Tv * levels(){ return mLevels; }
 	const Tv * levels() const { return mLevels; }
 
+	/// Set level at index (compile-time checked)
+	template <unsigned i>
+	Env& level(Tv v){
+		static_assert(i<(N+1), "Invalid level index");
+		levels()[i] = v;
+		return *this;
+	}
+
 	/// Set break-point values
 	template <class V>
 	Env& levels(const V* vals, int len){
@@ -299,13 +311,6 @@ public:
 	/// Set first five break-point levels
 	Env& levels(Tv a, Tv b, Tv c, Tv d, Tv e){ Tv v[]={a,b,c,d,e}; return levels(v,5); }
 
-	template <unsigned i>
-	Env& level(Tv v){
-		static_assert(i<(N+1), "Invalid level index");
-		levels()[i] = v;
-		return *this;
-	}
-
 	/// Set maximum level
 	Env& maxLevel(Tv v);
 
@@ -469,24 +474,50 @@ template <class T=real, class Td=GAM_DEFAULT_DOMAIN>
 class Decay : public Td{
 public:
 
-	/// \param[in] decay	Number of units until initial value decays -60 dB
+	/// \param[in] decay_	Number of units until initial value decays -60 dB
 	/// \param[in] val		Intial value
-	Decay(T decay=T(1), T val=T(1));
+	Decay(T decay_=T(1), T val=T(1))
+	:	mVal(val)
+	{
+		onDomainChange(1);
+		decay(decay_);
+	}
 
-	T decay() const;		///< Returns -60 dB decay length
-	bool done(T thresh=T(0.001)) const; ///< Returns whether value is below threshold
-	T value() const;		///< Returns current value
+	/// Set number of units for curve to decay -60 dB
+	Decay& decay(T v){
+		mDcy = v;
+		mMul = scl::t60(v * Td::spu());
+		return *this;
+	}
 
-	T operator()();			///< Generate next sample
-	
-	void decay(T v);		///< Set number of units for curve to decay -60 dB
+	/// Set current value
+	Decay& value(T v){ mVal = v; return *this; }
 
-	void value(T v);		///< Set current value
+	/// Reset envelope and assign amplitude
+	Decay& reset(T amp=T(1)){ return value(amp); }
 
-	void reset(T amp=T(1));	///< Reset envelope and assign amplitude
-	void finish(T amp=T(0.001)); ///< Jump to end of envelope
+	/// Jump to end of envelope
+	Decay& finish(T amp=T(0.001)){ return value(amp); }
 
-	void onDomainChange(double r);
+
+	/// Generate next sample
+	T operator()(){
+		T o = mVal;
+		mVal *= mMul;
+		return o;
+	}
+
+	/// Returns -60 dB decay length
+	T decay() const { return mDcy; }
+
+	/// Returns whether value is below threshold
+	bool done(T thresh=T(0.001)) const { return mVal < thresh; }
+
+	/// Returns current value
+	T value() const { return mVal; }
+
+
+	void onDomainChange(double /*r*/){ decay(mDcy); }
 
 protected:
 	T mVal, mMul, mDcy;
@@ -513,8 +544,9 @@ public:
 	:	mDelay(closingDelay), mRemain(closingDelay), mThresh(threshold), mClosed(0)
 	{}
 
-	/// Check whether gate is closed
-	bool done() const { return mClosed; }
+
+	/// Set closing delay
+	Gate& delay(double v){ mDelay=mRemain=v; return *this; }
 
 	/// Filter value
 	T operator()(const T& v){		
@@ -527,9 +559,10 @@ public:
 		}
 		return open();
 	}
-	
-	/// Set closing delay
-	Gate& delay(double v){ mDelay=mRemain=v; return *this; }
+
+
+	/// Check whether gate is closed
+	bool done() const { return mClosed; }
 
 protected:
 	double mDelay, mRemain;
@@ -557,34 +590,64 @@ public:
 	/// \param[in] start	Start value
 	/// \param[in] end		End value
 	/// \param[in] phase	Start phase along segment, in [0,1)
-	Seg(Tp len=0.5, Tv start=1, Tv end=0, Tp phase=0):
-		mFreq((Tp)1/len), mAcc(0, phase), mIpl(start)
-	{
-		mIpl.push(end);
-		onDomainChange(1);
+	Seg(Tp len=0.5, Tv start=1, Tv end=0, Tp phase=0){
+		length(len);
+		levels(start, end);
+		this->phase(phase);
 	}
 
 
-	/// Returns whether envelope is done
-	bool done() const { return mAcc.val >= Tp(1); }
+	/// Set frequency of envelope
+	Seg& freq(Tp v){
+		mFreq = scl::abs(v);
+		mAcc.add = v * Tp(Td::ups());
+		return *this;
+	}
 
-	/// Get current value
-	Tv val() const { return mIpl(scl::min(mAcc.val, Tp(1))); }
+	/// Set length, in domain units
+	Seg& length(Tp v){
+		return v > Tp(Td::ups()) ? freq(Tp(1)/v) : freq(Td::spu());
+	}
 
-	
-	/// Set new end value.  Start value is set to current value.
-	void operator= (Tv v){
-		mIpl.val(mIpl(scl::min(mAcc.val, Tp(1))));
-		mIpl.push(v);
-		reset();
+	/// Set length, in domain units
+	Seg& period(Tp v){ return length(v); }
+
+	/// Set phase along segment
+	Seg& phase(Tp v){ mAcc = v; return *this; }
+
+	/// Reset envelope
+	Seg& reset(){ return phase(Tp(0)); }
+
+	/// Set start and end values and reset
+	Seg& levels(Tv start, Tv end){
+		mIpl.val(start);
+		mIpl.push(end);
+		return reset();
+	}
+
+	/// Set maximum level
+	Seg& maxLevel(Tv v){
+		auto maxAbs = mIpl.maxAbs();
+		if(maxAbs == Tv(0)) mIpl.set(v);
+		else{
+			auto mul = v/maxAbs;
+			for(auto& val : mIpl.vals) val *= mul;
+		}
+		return *this;
+	}
+
+	/// Get maximum level
+	Tv maxLevel() const { return mIpl.maxAbs(); }
+
+	/// Set new end value (start value set to current value)
+	Seg& operator= (Tv v){
+		return levels(mIpl(scl::min(mAcc.val, Tp(1))), v);
 	}
 
 	/// Generate next value
 	Tv operator()(){
 		if(done()) return mIpl.val();
-		Tp f = mAcc.val;
-		mAcc();
-		return mIpl(f);
+		return next();
 	}
 
 	/// Generates a new end point from a generator when the segment end is reached
@@ -597,26 +660,15 @@ public:
 			mIpl.push(g());
 			mAcc.val = mAcc.val - Tp(1); // wrap phase
 		}
-		Tp f = mAcc.val;
-		mAcc();
-		return mIpl(f);
+		return next();
 	}
-	
-	/// Set frequency of envelope
-	void freq(Tp v){ mFreq = v; mAcc.add = v * Tp(Td::ups()); }
-	
-	/// Set length, in domain units
-	void length(Tp v){ freq(Tp(1)/v); }
 
-	/// Set length, in domain units
-	void period(Tp v){ length(v); }
 
-	/// Set phase along segment
-	void phase(Tp v){ mAcc = v; }
-
-	/// Reset envelope
-	void reset(){ phase(Tp(0)); }
+	/// Returns whether envelope is done
+	bool done() const { return mAcc.val >= Tp(1); }
 
+	/// Get current value
+	Tv value() const { return mIpl(scl::min(mAcc.val, Tp(1))); }
 
 	Si<Tv>& ipol(){ return mIpl; }
 
@@ -626,6 +678,12 @@ protected:
 	Tp mFreq;
 	gen::RAdd<Tp> mAcc;
 	Si<Tv> mIpl;
+
+	Tv next(){
+		auto frac = mAcc.val;
+		mAcc();
+		return mIpl(frac);
+	}
 };
 
 
@@ -646,37 +704,41 @@ public:
 	{
 		onDomainChange(1);
 	}
-	
-	/// Returns whether envelope is done
-	bool done() const { return mCurve.value() >= T(1); }
-	
+
+
+	/// Set curvature (negative for fast approach, positive for slow approach)
+	SegExp& curve(T v){ return set(mLen, v); }
+
+	/// Set length in domain units.
+	SegExp& period(T v){ return set(v, mCrv); }
+
+	SegExp& reset(){ mCurve.reset(); return *this; }
+
+	/// Set length and curvature
+	SegExp& set(T len, T crv){
+		mLen = len; mCrv = crv;
+		mCurve.set(len * Td::spu(), crv);
+		return *this;
+	}
+
+	/// Set new end value (start value set to current value)
+	SegExp& operator= (T v){
+		mVal1 = ipl::linear(scl::min(mCurve.value(), T(1)), mVal1, mVal0);
+		mVal0 = v;
+		mCurve.reset();
+		return *this;
+	}
+
 	/// Generate next value
 	T operator()(){
 		if(done()) return mVal0;
 		return ipl::linear(scl::min(mCurve(), T(1)), mVal1, mVal0);
 	}
 	
-	/// Set new end value.  Start value is set to current value.
-	void operator= (T v){
-		mVal1 = ipl::linear(scl::min(mCurve.value(), T(1)), mVal1, mVal0);
-		mVal0 = v;
-		mCurve.reset();
-	}
-	
-	/// Set curvature.  Negative gives faster change, positive gives slower change.
-	void curve(T v){ set(mLen, v); }
-	
-	/// Set length in domain units.
-	void period(T v){ set(v, mCrv); }
 
-	void reset(){ mCurve.reset(); }
+	/// Returns whether envelope is done
+	bool done() const { return mCurve.value() >= T(1); }
 
-	/// Set length and curvature
-	void set(T len, T crv){
-		mLen = len; mCrv = crv;
-		mCurve.set(len * Td::spu(), crv);
-	}
-	
 	void onDomainChange(double r){ set(mLen, mCrv); }
 	
 protected:
@@ -946,50 +1008,5 @@ Env<N,Tv,Tp,Td>& Env<N,Tv,Tp,Td>::maxLevel(Tv v){
 	return *this;
 }
 
-
-
-template <class T, class Td>
-Decay<T,Td>::Decay(T decay_, T val)
-:	mVal(val)
-{
-	onDomainChange(1);
-	decay(decay_);
-}
-
-template <class T, class Td>
-inline T Decay<T,Td>::operator()(){
-	T o = mVal;
-	mVal *= mMul;
-	return o;
-}
-
-template <class T, class Td>
-void Decay<T,Td>::decay(T v){
-	mDcy = v;
-	mMul = scl::t60(v * Td::spu());
-}
-
-template <class T, class Td>
-void Decay<T,Td>::reset(T amp){ mVal = amp; }
-
-template <class T, class Td>
-void Decay<T,Td>::finish(T amp){ mVal = amp; }
-
-template <class T, class Td>
-void Decay<T,Td>::value(T v){ mVal = v; }
-
-template <class T, class Td>
-T Decay<T,Td>::decay() const { return mDcy; }
-
-template <class T, class Td>
-inline bool Decay<T,Td>::done(T thr) const { return mVal < thr; }
-
-template <class T, class Td>
-T Decay<T,Td>::value() const { return mVal; }
-
-template <class T, class Td>
-void Decay<T,Td>::onDomainChange(double /*r*/){ decay(mDcy); }
-
-
 } // gam::
 #endif
