@@ -94,10 +94,16 @@ public:
 
 	void onDomainChange(double r);
 
-//protected:
+protected:
+	static uint32_t f2i(float v);
+	static double i2f(uint32_t v);
+	static constexpr uint32_t maxUInt(){ return ~uint32_t(0); }
+	static constexpr double maxUIntReal(){ return double(maxUInt())+1.; }
+	static constexpr uint32_t maskSign(){ return uint32_t(1)<<(sizeof(uint32_t)*8-1); }
+
 private:
 	float mFreq;		// Current frequency
-	double mFreqToInt;
+	double mFreqToUInt;	// Factor to convert real to fixed-point freq
 	uint32_t mPhaseI;	// Current fixed-point phase in [0, 2^32)
 	uint32_t mFreqI;	// Current fixed-point frequency
 	Sp mSp;
@@ -767,7 +773,7 @@ public:
 
 	/// Get modifier value
 	uint32_t modI() const { return mMod; }
-	double mod() const { return mMod / 4294967296.; }
+	double mod() const { return this->i2f(mMod); }
 
 	/// Set frequency
 	void freq(float v);
@@ -1044,43 +1050,40 @@ private:
 
 // Implementation_______________________________________________________________
 
-namespace{
-
-// Convert unit floating-point to fixed-point integer.
-// 32-bit float is good enough here since [0.f, 1.f) uses 29 bits.
-inline uint32_t mapFI(float v){
-	//return scl::unitToUInt(v);
-	//return (uint32_t)(v * 4294967296.);
-	return castIntRound(v * 4294967296.);
-}
-
-// Convert fixed-point integer to unit floating-point.
-inline double mapIF(uint32_t v){
-	return v/4294967296.;
-	//return uintToUnit<float>(v); // not enough precision
-}
-
-};
-
-
 //---- Accum
 template<class Sp, class Td>
 Accum<Sp,Td>::Accum(float f, float p)
-:	mFreq(f), mFreqToInt(4294967296.), mFreqI(0)
+:	mFreq(f), mFreqToUInt(maxUIntReal()), mFreqI(0)
 {
 	onDomainChange(1);
 	phase(p);
 }
 
+// Convert unit floating-point to fixed-point integer
+// 32-bit float is good enough here since [0.f, 1.f) uses 29 bits.
+template<class Sp, class Td>
+inline uint32_t Accum<Sp,Td>::f2i(float v){
+	//return scl::unitToUInt(v);
+	//return {v * maxUIntReal()};
+	return castIntRound(v * maxUIntReal());
+}
+
+// Convert fixed-point integer to unit floating-point
+template<class Sp, class Td>
+inline double Accum<Sp,Td>::i2f(uint32_t v){
+	return v/maxUIntReal();
+	//return uintToUnit<float>(v); // not enough precision
+}
+
 template<class Sp, class Td>
 inline uint32_t Accum<Sp,Td>::mapFreq(float v) const {
-	//return mapFI(v * Td::ups());
-	return castIntRound(v * mFreqToInt);
+	//return f2i(v * Td::ups());
+	return castIntRound(v * mFreqToUInt);
 }
 
 template<class Sp, class Td>
 void Accum<Sp,Td>::onDomainChange(double /*r*/){ //printf("Accum: onDomainChange (%p)\n", this);
-	mFreqToInt = 4294967296. / Td::spu();
+	mFreqToUInt = maxUIntReal() / Td::spu();
 	freq(mFreq);
 }
 
@@ -1093,70 +1096,70 @@ inline void Accum<Sp,Td>::freq(float v){
 template<class Sp, class Td>
 inline void Accum<Sp,Td>::freqI(uint32_t v){
 	mFreqI= v;
-	mFreq = mapIF(v) * Td::spu();
+	mFreq = i2f(v) * Td::spu();
 }
 
 template<class Sp, class Td> inline void Accum<Sp,Td>::freqAdd(float v){ phaseAdd(v*Td::ups()); }
 template<class Sp, class Td> inline void Accum<Sp,Td>::freqMul(float v){ freqAdd((v-1.f)*freq()); }
 
 template<class Sp, class Td> inline void Accum<Sp,Td>::period(float v){ freq(1.f/v); }
-template<class Sp, class Td> inline void Accum<Sp,Td>::phase(float v){ mPhaseI = mapFI(v); }
-template<class Sp, class Td> inline void Accum<Sp,Td>::phaseAdd(float v){ mSp(mPhaseI, mapFI(v)); }
-template<class Sp, class Td> void Accum<Sp,Td>::phaseMax(){ mPhaseI = 0xffffffff; }
+template<class Sp, class Td> inline void Accum<Sp,Td>::phase(float v){ mPhaseI = f2i(v); }
+template<class Sp, class Td> inline void Accum<Sp,Td>::phaseAdd(float v){ mSp(mPhaseI, f2i(v)); }
+template<class Sp, class Td> void Accum<Sp,Td>::phaseMax(){ mPhaseI = maxUInt(); }
 
 template<class Sp, class Td>
 inline bool Accum<Sp,Td>::done() const { return mSp.done(phaseI()); }
 
 template<class Sp, class Td>
 inline bool Accum<Sp,Td>::cycled() const {
-	uint32_t prev = phaseI();
-	Sp temp = mSp;
+	auto prev = phaseI();
+	auto temp = mSp;
 	temp(prev, ~freqI());
-	return ((~phaseI() & prev) & 0x80000000) != 0;
+	return ((~phaseI() & prev) & maskSign()) != 0;
 }
 
 template<class Sp, class Td> inline float Accum<Sp,Td>::freq() const { return mFreq; }
 template<class Sp, class Td> inline uint32_t Accum<Sp,Td>::freqI() const { return mFreqI; }
-template<class Sp, class Td> inline float Accum<Sp,Td>::freqUnit() const { return float(mapIF(mFreqI)); }
+template<class Sp, class Td> inline float Accum<Sp,Td>::freqUnit() const { return float(i2f(mFreqI)); }
 template<class Sp, class Td> inline float Accum<Sp,Td>::period() const { return 1.f/freq(); }
-template<class Sp, class Td> inline float Accum<Sp,Td>::phase() const { return float(mapIF(mPhaseI)); }
+template<class Sp, class Td> inline float Accum<Sp,Td>::phase() const { return float(i2f(mPhaseI)); }
 template<class Sp, class Td> inline uint32_t Accum<Sp,Td>::phaseI() const { return mPhaseI; }
 
 template<class Sp, class Td> inline uint32_t Accum<Sp,Td>::nextPhase(float frqOffset){
-	uint32_t p = mPhaseI;
+	auto p = mPhaseI;
 	mSp(mPhaseI, mFreqI + mapFreq(frqOffset)); // apply phase inc strategy
 	return p;
 }
 
 template<class Sp, class Td> inline uint32_t Accum<Sp,Td>::nextPhase(){
-	uint32_t p = mPhaseI;
+	auto p = mPhaseI;
 	mSp(mPhaseI, mFreqI); // apply phase inc strategy
 	return p;
 }
 
 template<class Sp, class Td> inline bool Accum<Sp,Td>::operator()(){ return cycle(); }
 
-template<class Sp, class Td> inline bool Accum<Sp,Td>::cycle(){ return (cycles() & 0x80000000) != 0; }
+template<class Sp, class Td> inline bool Accum<Sp,Td>::cycle(){ return (cycles() & maskSign()) != 0; }
 
 //template<class Sp, class Td> inline uint32_t Accum<Sp,Td>::cycle(uint32_t mask){
 //	return cycles() & mask;
 //}
 
 template<class Sp, class Td> inline uint32_t Accum<Sp,Td>::cycles(){
-	uint32_t prev = phaseI();
+	auto prev = phaseI();
 	nextPhase();
 	return ~phaseI() & prev;
 }
 
 template<class Sp, class Td> inline bool Accum<Sp,Td>::once(){
-	uint32_t prev = phaseI();
+	auto prev = phaseI();
 	bool c = cycle();
 	if(c) mPhaseI = prev;
 	return c;
 }
 
 template<class Sp, class Td> inline bool Accum<Sp,Td>::seq(uint32_t pat){
-	uint32_t prev = phaseI();
+	auto prev = phaseI();
 	nextPhase();
 
 	// Did any of the 5 MSBs change?
@@ -1311,7 +1314,7 @@ template<class Sp, class Td> inline TLFO& TLFO::set(float f, float p, float m){
 	return mod(m);
 }
 template<class Sp, class Td> inline TLFO& TLFO::mod(double v){
-	return modI(castIntRound(v*4294967296.));
+	return modI(this->f2i(v));
 }
 template<class Sp, class Td> inline TLFO& TLFO::modI(uint32_t v){
 	mMod=v;
@@ -1319,18 +1322,18 @@ template<class Sp, class Td> inline TLFO& TLFO::modI(uint32_t v){
 }
 
 template<class Sp, class Td> inline float TLFO::line2(){
-	uint32_t m = scl::clip<uint32_t>(mMod, 0xffefffff, 512); // avoid div by zero
+	auto m = scl::clip<uint32_t>(mMod, 0xffefffff, 512); // avoid div by zero
 
 	/* Starts at 1
-	float r1 = scl::rampDown(phaseI());
-	float r2 = scl::rampDown(phaseI() + m); //*/
+	auto s1 = scl::sawDown(phaseI());
+	auto s2 = scl::sawDown(phaseI() + m); //*/
 
 	//* Starts at -1 (better for creating attack/decay like envelopes)
-	float r1 = scl::rampDown(phaseI() - m);
-	float r2 = scl::rampDown(phaseI()); //*/
+	auto s1 = scl::sawDown(phaseI() - m);
+	auto s2 = scl::sawDown(phaseI()); //*/
 
-	float p  = punUF(Expo2<float>() | (m >> 9)) - 2.f; // [0, 2);
-	float r = (r1*r1 - r2*r2)/(p*(2.f - p));
+	auto p  = punUF(Expo2<float>() | (m >> 9)) - 2.f; // to [0, 2)
+	auto r = (s1*s1 - s2*s2)/(p*(2.f - p));
 	nextPhase();
 	return r;
 }
@@ -1344,7 +1347,7 @@ DEF(sinPara(),	scl::sinPara(nextPhase()))
 DEF(cos(),		scl::sinFast(nextPhase() + uint32_t(1073741824)); )
 //DEF(cosCub(),		tri(); r *= 0.5f * r*r - 1.5f)
 DEF(cosCub(),	up(); r = -1.f - r*r*(4.f*scl::abs(r)-6.f) )
-DEF(down(),		scl::rampDown(nextPhase()))
+DEF(down(),		scl::sawDown(nextPhase()))
 DEF(even3(),	up(); float c=-2.598076211353315;/*-1.50*pow(3,0.50)*/ r *= (1.f-r*r)*c;)
 DEF(even5(),	up(); float c=-1.869185976526527;/*-1.25*pow(5,0.25)*/ r *= (1.f-scl::pow4(r))*c;)
 DEF(imp(),		scl::pulse(nextPhase(), this->freqI()) )
@@ -1353,15 +1356,15 @@ DEF(pulse(),	scl::pulse(nextPhase(), mMod))
 DEF(stair(),	scl::stair(nextPhase(), mMod))
 DEF(sqr(),		scl::square(nextPhase()))
 DEF(tri(),		scl::triangle(nextPhase()))
-DEF(up(),		scl::rampUp(nextPhase()))
-DEF(up2(),		scl::rampUp2(nextPhase(), mMod))
+DEF(up(),		scl::sawUp(nextPhase()))
+DEF(up2(),		scl::sawUp2(nextPhase(), mMod))
 DEF(S1(),		up(); float c=          -M_PI /  2; r = c*r)
 DEF(C2(),		up(); float c= scl::pow2(M_PI)/  4; r = c*(r*r - 1.f/3))
 DEF(S3(),		up(); float c= scl::pow3(M_PI)/ 12; r = c*(r*r*r - r))
 DEF(C4(),		up(); float c=-scl::pow4(M_PI)/ 48; float rr=r*r; r = c*(rr*(rr - 2.f) + 7.f/15))
 DEF(S5(),		up(); float c=-scl::pow5(M_PI)/240; float rr=r*r; r = c*r*(rr*(rr - 10.f/3) + 7.f/3))
 DEF(cosCubU(),	up(); r = r*r*(-2.f*scl::abs(r)+3.f))
-DEF(downU(),	scl::rampDownU(nextPhase()))
+DEF(downU(),	scl::sawDownU(nextPhase()))
 //DEF(hann(),	tri(); r = r * (0.25f * r*r - 0.75f) + 0.5f)
 DEF(hann(),		up(); r = 1.f + r*r*(2.f*scl::abs(r)-3.f))
 DEF(impU(),		scl::pulseU(nextPhase(), this->freqI()) )
@@ -1371,11 +1374,11 @@ DEF(pulseRange(), scl::pulseRange(nextPhase(), mMod))
 DEF(sqrU(),		scl::squareU(nextPhase()))
 DEF(stairU(),	scl::stairU(nextPhase(), mMod))
 DEF(triU(),		scl::triangleU(nextPhase()))
-DEF(upU(),		scl::rampUpU(nextPhase()))
-DEF(up2U(),		scl::rampUp2U(nextPhase(), mMod))
-DEF(patU(),		scl::rampUpU(nextPhase() & mMod))
+DEF(upU(),		scl::sawUpU(nextPhase()))
+DEF(up2U(),		scl::sawUp2U(nextPhase(), mMod))
+DEF(patU(),		scl::sawUpU(nextPhase() & mMod))
 
-DEF(patU(uint32_t mul), scl::rampUpU((nextPhase() & mMod) * mul))
+DEF(patU(uint32_t mul), scl::sawUpU((nextPhase() & mMod) * mul))
 
 /* The input domain for these is [-1,1] corresponding to [-pi,pi], but that will
 give us an upside-down sine. We therefore use a downward ramp to flip the wave
@@ -1406,7 +1409,7 @@ DWO<Sp,Td>::DWO(float f, float p, float m)
 
 template<class Sp, class Td>
 inline DWO<Sp,Td>& DWO<Sp,Td>::mod(double v){
-	return modI(castIntRound(v*4294967296.));
+	return modI(this->f2i(v));
 }
 template<class Sp, class Td>
 inline DWO<Sp,Td>& DWO<Sp,Td>::modI(uint32_t v){
@@ -1417,7 +1420,7 @@ inline DWO<Sp,Td>& DWO<Sp,Td>::modI(uint32_t v){
 template <class Sp, class Td>
 inline void DWO<Sp,Td>::freq(float v){
 	Base::freq(v);
-	float freq1 = this->freqUnit();
+	auto freq1 = this->freqUnit();
 	// Very low freq will produce quantization noise
 	if(freq1 < 1e-5) freq1 = 1e-5;
 	mGain = -0.25/freq1;
@@ -1425,58 +1428,52 @@ inline void DWO<Sp,Td>::freq(float v){
 
 /* Ideally we would use a differencing filter, however, it has a serious shortcoming. Any sudden changes in phase (or frequency) will lead a large amplitude impulse in the output which becomes worse the lower the frequency. A related problem is what to initialize the filter's previous input sample to. Instead of a filter, we use an analytic approach which subtracts two phase-shifted waveforms.
 */
-namespace{
-	inline float para01(uint32_t p){
-		float s = scl::rampUp(p);
-		return s*s;
-	}
-	inline float triangle02(uint32_t p){
-		p = Expo4<float>() | (p >> 9); // [4, 8)
-		return scl::abs(punUF(p) - 6.f);
-	}
-}
-
 template <class Sp, class Td>
 inline float DWO<Sp,Td>::up(){
 	/*
-	float s = para01(this->nextPhase());
+	auto s = scl::paraU(this->nextPhase());
 	return diff(s);//*/
 	//*
-	uint32_t p = this->nextPhase();
-	float s = para01(p);
-	float t = para01(p + this->freqI());
+	auto p = this->nextPhase();
+	auto s = scl::paraU(p);
+	auto t = scl::paraU(p + this->freqI());
 	return (s - t)*mGain;//*/
 }
 
 template <class Sp, class Td>
 inline float DWO<Sp,Td>::down(){
-	/*float s = para01(this->nextPhase());
+	/*auto s = scl::paraU(this->nextPhase());
 	return diff(-s);*/
-	uint32_t p = this->nextPhase();
-	float s = para01(p);
-	float t = para01(p + this->freqI());
+	auto p = this->nextPhase();
+	auto s = scl::paraU(p);
+	auto t = scl::paraU(p + this->freqI());
 	return (t - s)*mGain;
 }
 
 template <class Sp, class Td>
 inline float DWO<Sp,Td>::sqr(){
+	// Unipolar triangle in [0,2]
+	auto triangle02 = [](uint32_t p){
+		p = Expo4<float>() | (p >> 9); // [4, 8)
+		return scl::abs(punUF(p) - 6.f);
+	};
 	/*
 	float s = triangle02(this->nextPhase());
 	return diff(s);//*/
 	//*
-	uint32_t p = this->nextPhase();
-	float s = triangle02(p);
-	float t = triangle02(p + this->freqI());
+	auto p = this->nextPhase();
+	auto s = triangle02(p);
+	auto t = triangle02(p + this->freqI());
 	return (t - s)*mGain;//*/
 }
 
 template <class Sp, class Td>
 inline float DWO<Sp,Td>::para(){
-	static const float c = (-M_PI*M_PI*M_PI/12.)*0.5;
-	uint32_t p = this->nextPhase();
-	float s = scl::rampUp(p);
+	static constexpr float c = (-M_PI*M_PI*M_PI/12.)*0.5;
+	auto p = this->nextPhase();
+	auto s = scl::sawUp(p);
 	s = s*s*s - s;
-	float t = scl::rampUp(p + this->freqI());
+	auto t = scl::sawUp(p + this->freqI());
 	t = t*t*t - t;
 	return (t - s)*c*mGain;
 }
@@ -1484,31 +1481,31 @@ inline float DWO<Sp,Td>::para(){
 template <class Sp, class Td>
 inline float DWO<Sp,Td>::tri(){
 	/*
-	float s = scl::sinPara(this->nextPhase())*0.5f;
+	auto s = scl::sinPara(this->nextPhase())*0.5f;
 	return diff(s);//*/
 	//*
-	uint32_t p = this->nextPhase();
-	float s = scl::sinPara(p);
-	float t = scl::sinPara(p + this->freqI());
+	auto p = this->nextPhase();
+	auto s = scl::sinPara(p);
+	auto t = scl::sinPara(p + this->freqI());
 	return (t - s)*-0.5f*mGain;//*/
 }
 
 template <class Sp, class Td>
 inline float DWO<Sp,Td>::pulse(){
 	/*
-	uint32_t p = this->nextPhase();
-	float s1 = para01(p);
-	float s2 = para01(p + mMod);
+	auto p = this->nextPhase();
+	auto s1 = scl::paraU(p);
+	auto s2 = scl::paraU(p + mMod);
 	return diff((s1 - s2)*0.5f);//*/
 	//*
-	uint32_t p = this->nextPhase();
-	float s1 = para01(p);
-	float s2 = para01(p - mMod);
-	float s  = s1 - s2;
-	uint32_t q = p + this->freqI();
-	float t1 = para01(q);
-	float t2 = para01(q - mMod);
-	float t  = t1 - t2;
+	auto p = this->nextPhase();
+	auto s1 = scl::paraU(p);
+	auto s2 = scl::paraU(p - mMod);
+	auto s  = s1 - s2;
+	auto q = p + this->freqI();
+	auto t1 = scl::paraU(q);
+	auto t2 = scl::paraU(q - mMod);
+	auto t  = t1 - t2;
 	return (t - s)*0.5f*mGain;//*/
 }
 
@@ -1519,7 +1516,7 @@ inline float DWO<Sp,Td>::imp(){
 
 /*template <class Sp, class Td>
 inline float DWO<Sp,Td>::diff(float v){
-	float res = (v - mPrev)*mGain;
+	auto res = (v - mPrev)*mGain;
 	mPrev = v;
 	return res;
 }*/
