@@ -1,5 +1,4 @@
 #pragma once
-#include <cmath>
 #include <halp/controls.hpp>
 #include <halp/dynamic_port.hpp>
 #include <halp/meta.hpp>
@@ -9,11 +8,14 @@ namespace ao
 {
 struct Spread
 {
-  halp_meta(name, "Spread")
-  halp_meta(c_name, "avnd_Spread")
+  halp_meta(name, "Spread array")
+  halp_meta(c_name, "avnd_spread")
   halp_meta(author, "Jean-Michaël Celerier")
   halp_meta(category, "Control/Mappings")
-  halp_meta(description, "Spread N inputs from a list")
+  halp_meta(
+      description,
+      "Spread N inputs from a list: from [123, 'foo', 4.56] to 123 on inlet, 0, 'foo' "
+      "on inlet 1 and 4.56 on inlet 2")
   halp_meta(
       manual_url, "https://ossia.io/score-docs/processes/mapping-utilities.html#spread")
   halp_meta(uuid, "cd6dc025-1d8e-4b73-868a-599df81667e4")
