@@ -1,10 +1,11 @@
 #pragma once
 
 #include <cmath>
+#include <halp/modules.hpp>
 
+HALP_MODULE_EXPORT
 namespace halp
 {
-static const constexpr double pi = 3.141592653589793238462643383279502884;
 
 // A basic smooth specification
 template <int T>
@@ -21,6 +22,7 @@ struct milliseconds_smooth
 template <int T>
 struct exp_smooth
 {
+  static const constexpr double pi = 3.141592653589793238462643383279502884;
   static constexpr auto ratio(double sample_rate) noexcept
   {
     return std::exp(-2. * pi / (T * 1e-3 * sample_rate));
