@@ -20,6 +20,7 @@
 
 #include <async_mqtt5/detail/async_mutex.hpp>
 #include <async_mqtt5/detail/async_traits.hpp>
+#include <async_mqtt5/detail/log_invoke.hpp>
 
 #include <async_mqtt5/impl/endpoints.hpp>
 #include <async_mqtt5/impl/read_op.hpp>
@@ -33,13 +34,15 @@ using error_code = boost::system::error_code;
 
 template <
 	typename StreamType,
-	typename StreamContext = std::monostate
+	typename StreamContext = std::monostate,
+	typename LoggerType = noop_logger
 >
 class autoconnect_stream {
 public:
-	using self_type = autoconnect_stream<StreamType, StreamContext>;
+	using self_type = autoconnect_stream<StreamType, StreamContext, LoggerType>;
 	using stream_type = StreamType;
 	using stream_context_type = StreamContext;
+	using logger_type = LoggerType;
 	using executor_type = typename stream_type::executor_type;
 private:
 	using stream_ptr = std::shared_ptr<stream_type>;
@@ -47,32 +50,33 @@ private:
 	executor_type _stream_executor;
 	async_mutex _conn_mtx;
 	asio::steady_timer _read_timer, _connect_timer;
-	endpoints _endpoints;
+	endpoints<logger_type> _endpoints;
 
 	stream_ptr _stream_ptr;
 	stream_context_type& _stream_context;
 
+	log_invoke<logger_type>& _log;
+
 	template <typename Owner, typename Handler>
 	friend class read_op;
 
 	template <typename Owner, typename Handler>
 	friend class write_op;
 
-	template <typename Stream>
+	template <typename Owner>
 	friend class reconnect_op;
 
-	template <typename Owner, typename DisconnectContext>
-	friend class disconnect_op;
-
 public:
 	autoconnect_stream(
-		const executor_type& ex, stream_context_type& context
+		const executor_type& ex, stream_context_type& context,
+		log_invoke<logger_type>& log
 	) :
 		_stream_executor(ex),
 		_conn_mtx(_stream_executor),
 		_read_timer(_stream_executor), _connect_timer(_stream_executor),
-		_endpoints(_stream_executor, _connect_timer),
-		_stream_context(context)
+		_endpoints(_stream_executor, _connect_timer, log),
+		_stream_context(context),
+		_log(log)
 	{
 		replace_next_layer(construct_next_layer());
 	}
@@ -106,7 +110,7 @@ public:
 	}
 
 	void open() {
-		open_lowest_layer(_stream_ptr);
+		open_lowest_layer(_stream_ptr, asio::ip::tcp::v4());
 	}
 
 	void cancel() {
@@ -169,10 +173,15 @@ public:
 	}
 
 private:
-	static void open_lowest_layer(stream_ptr sptr) {
+
+	log_invoke<logger_type>& log() {
+		return _log;
+	}
+
+	static void open_lowest_layer(const stream_ptr& sptr, asio::ip::tcp protocol) {
 		error_code ec;
 		auto& layer = lowest_layer(*sptr);
-		layer.open(asio::ip::tcp::v4(), ec);
+		layer.open(protocol, ec);
 		layer.set_option(asio::socket_base::reuse_address(true), ec);
 		layer.set_option(asio::ip::tcp::no_delay(true), ec);
 	}
@@ -189,9 +198,9 @@ private:
 		return sptr;
 	}
 
-	stream_ptr construct_and_open_next_layer() const {
+	stream_ptr construct_and_open_next_layer(asio::ip::tcp protocol) const {
 		auto sptr = construct_next_layer();
-		open_lowest_layer(sptr);
+		open_lowest_layer(sptr, protocol);
 		return sptr;
 	}
 
@@ -212,11 +221,11 @@ private:
 		using Signature = void (error_code);
 
 		auto initiation = [](auto handler, self_type& self, stream_ptr s) {
-			reconnect_op { self, std::move(handler) }.perform(s);
+			reconnect_op { self, std::move(handler) }.perform(std::move(s));
 		};
 
 		return asio::async_initiate<CompletionToken, Signature>(
-			initiation, token, std::ref(*this), s
+			initiation, token, std::ref(*this), std::move(s)
 		);
 	}
 };
