@@ -3,6 +3,8 @@
 #include <libremidi/backends/winmm/midi_out.hpp>
 #include <libremidi/backends/winmm/observer.hpp>
 
+#include <string_view>
+
 // Default for Windows is to add an identifier to the port names; this
 // flag can be defined (e.g. in your project file) to disable this behaviour.
 // #define LIBREMIDI_DO_NOT_ENSURE_UNIQUE_PORTNAMES
@@ -28,8 +30,8 @@ struct winmm_backend
   using midi_out_configuration = winmm_output_configuration;
   using midi_observer_configuration = winmm_observer_configuration;
   static const constexpr auto API = libremidi::API::WINDOWS_MM;
-  static const constexpr auto name = "winmm";
-  static const constexpr auto display_name = "Windows Multimedia";
+  static const constexpr std::string_view name = "winmm";
+  static const constexpr std::string_view display_name = "Windows Multimedia";
 
   static constexpr inline bool available() noexcept { return true; }
 };
