@@ -1,8 +1,6 @@
 #pragma once
 #include <libremidi/api.hpp>
-#include <libremidi/config.hpp>
-
-#include <any>
+#include <libremidi/configurations.hpp>
 
 namespace libremidi
 {
@@ -24,7 +22,9 @@ public:
 struct shared_configurations
 {
   std::shared_ptr<shared_context> context;
-  std::any observer, in, out;
+  observer_api_configuration observer;
+  input_api_configuration in;
+  output_api_configuration out;
 };
 
 LIBREMIDI_EXPORT
