@@ -16,7 +16,7 @@ int main(int argc, char** argv)
   using conf = ossia::net::osc_protocol_configuration;
   ossia::net::generic_device device{
       ossia::net::make_osc_protocol(
-          ctx, {conf::HOST, conf::OSC1_1, conf::SLIP,
+          ctx, {conf::HOST, conf::OSC1_1, conf::SLIP, conf::NEVER_BUNDLE,
                 ossia::net::ws_server_configuration{1234}}),
       "P"};
 
