@@ -225,20 +225,7 @@ public:
     activated = true;
   }
 
-  ~jack_engine() override
-  {
-    stop();
-
-    if(m_client)
-    {
-      jack_client_t* client = *m_client;
-      jack_deactivate(client);
-      for(auto port : this->input_ports)
-        jack_port_unregister(client, port);
-      for(auto port : this->output_ports)
-        jack_port_unregister(client, port);
-    }
-  }
+  ~jack_engine() override { stop(); }
 
   bool running() const override
   {
@@ -247,6 +234,23 @@ public:
     return activated;
   }
 
+  void stop() override
+  {
+    audio_engine::stop();
+
+    if(m_client)
+    {
+      jack_client_t* client = *m_client;
+      activated = false;
+      jack_deactivate(client);
+      for(auto port : this->input_ports)
+        jack_port_unregister(client, port);
+      for(auto port : this->output_ports)
+        jack_port_unregister(client, port);
+      m_client.reset();
+    }
+  }
+
 private:
   static int
   clear_buffers(jack_engine& self, jack_nframes_t nframes, std::size_t outputs)
