@@ -1163,12 +1163,12 @@ TEST_CASE("test_oscquery_osc_to_ws", "test_oscquery_osc_to_ws")
   using conf = ossia::net::osc_protocol_configuration;
 
   auto osc = ossia::net::make_osc_protocol(
-      ctx,
-      {.mode = conf::HOST,
-       .version = conf::OSC1_1,
-       .transport = ossia::net::udp_configuration{
-           {.local = std::nullopt,
-            .remote = ossia::net::outbound_socket_configuration{"127.0.0.1", shared}}}});
+      ctx, {.mode = conf::HOST,
+            .version = conf::OSC1_1,
+            .transport = ossia::net::udp_configuration{
+                {.local = std::nullopt,
+                 .remote = ossia::net::outbound_socket_configuration{
+                     .host = "127.0.0.1", .port = shared}}}});
 
   //server change goes to mirror
   server_param->push_value(2.0f);
