@@ -1443,33 +1443,30 @@ void canvas_update_dsp(void)
 }
 
 /* the "dsp" message to pd starts and stops DSP computation, and, if
-appropriate, also opens and closes the audio device. On exclusive-access
+appropriate, also opens and closes the audio device.  On exclusive-access
 APIs such as ALSA, MMIO, and ASIO (I think) it's appropriate to close the
 audio devices when not using them; but jack behaves better if audio I/O
-simply keeps running. Also, we want to preserve any connections made between
-Pd and other Jack clients. This is wasteful of CPU cycles but we do it anyway
+simply keeps running.  This is wasteful of CPU cycles but we do it anyway
 and can perhaps regard this is a design flaw in jack that we're working around
-here. The function audio_shouldkeepopen() is provided by s_audio.c to tell us
-that we should elide the step of closing audio when DSP is turned off.*/
+here.  The function audio_shouldkeepopen() is provided by s_audio.c to tell
+us that we should elide the step of closing audio when DSP is turned off.*/
 
 void glob_dsp(void *dummy, t_symbol *s, int argc, t_atom *argv)
 {
+    int newstate;
     if (argc)
     {
-        int newstate = atom_getfloat(argv);
+        newstate = atom_getfloatarg(0, argc, argv);
         if (newstate && !THISGUI->i_dspstate)
         {
-                /* if audio should be kept open, we don't reopen the device,
-                unless it really has been closed (for whatever reason) */
-            if (!audio_shouldkeepopen() || !audio_isopen())
-                sys_reopen_audio();
+            sys_set_audio_state(1);
             canvas_start_dsp();
         }
         else if (!newstate && THISGUI->i_dspstate)
         {
             canvas_stop_dsp();
             if (!audio_shouldkeepopen())
-                sys_close_audio();
+                sys_set_audio_state(0);
         }
     }
     else post("dsp state %d", THISGUI->i_dspstate);
