@@ -15,7 +15,7 @@ proc open_file {filename} {
     set directory [file normalize [file dirname $filename]]
     set basename [file tail $filename]
     if { ! [file exists $filename]} {
-        ::pdwindow::post [_ "ignoring '%s': doesn't exist" $filename]
+        ::pdwindow::post [format [_ "ignoring '%s': doesn't exist"] $filename]
         ::pdwindow::post "\n"
         # remove from recent files
         ::pd_guiprefs::update_recentfiles $filename true
@@ -28,7 +28,7 @@ proc open_file {filename} {
         # now this is done in pd_guiprefs
         ::pd_guiprefs::update_recentfiles $filename
     } else {
-        ::pdwindow::post [_ "ignoring '%s': doesn't look like a Pd file" $filename]
+        ::pdwindow::post [format [_ "ignoring '%s': doesn't look like a Pd file"] $filename]
         ::pdwindow::post "\n"
     }
 }
