@@ -25,6 +25,10 @@ Distributed under the Boost Software License, Version 1.0.
 #ifndef LLFIO_DYNAMIC_THREAD_POOL_GROUP_H
 #define LLFIO_DYNAMIC_THREAD_POOL_GROUP_H
 
+#ifndef LLFIO_DISABLE_DEPRECATION_WARNINGS
+#warning "Dynamic thread pool groups are deprecated and scheduled for removal soon"
+#endif
+
 #include "deadline.h"
 
 #include <memory>  // for unique_ptr and shared_ptr
@@ -35,6 +39,8 @@ Distributed under the Boost Software License, Version 1.0.
 #pragma warning(disable : 4275)  // dll interface
 #endif
 
+//! \file dynamic_thread_pool_group.hpp Provides a dynamic thread pool.
+
 LLFIO_V2_NAMESPACE_EXPORT_BEGIN
 
 class dynamic_thread_pool_group_impl;
@@ -50,6 +56,8 @@ namespace detail
 /*! \class dynamic_thread_pool_group
 \brief Work group within the global dynamic thread pool.
 
+\warning This is deprecated and scheduled for removal in 2025.
+
 Some operating systems provide a per-process global kernel thread pool capable of
 dynamically adjusting its kernel thread count to how many of the threads in
 the pool are currently blocked. The platform will choose the exact strategy used,
@@ -183,6 +191,7 @@ implementation).
 class LLFIO_DECL dynamic_thread_pool_group
 {
   friend class dynamic_thread_pool_group_impl;
+
 public:
   //! An individual item of work within the work group.
   class work_item
