@@ -76,8 +76,10 @@ Distributed under the Boost Software License, Version 1.0.
 #ifndef OUTCOME_C_INLINE
 #if __STDC_VERSION__ >= 199900L || __cplusplus > 0
 #define OUTCOME_C_INLINE inline
-#elif defined(__GNUC__) || defined(__clang__)
+#elif defined(__GNUC__) || defined(__clang__) || defined(_MSC_VER)
 #define OUTCOME_C_INLINE __inline
+#else
+#define OUTCOME_C_INLINE
 #endif
 #endif
 
@@ -121,9 +123,9 @@ extern "C"
 
   extern OUTCOME_C_WEAK void outcome_make_result_status_code_failure_posix(void *out, size_t bytes, size_t offset, int errcode);
   extern OUTCOME_C_WEAK void outcome_make_result_status_code_failure_system(void *out, size_t bytes, size_t offset, intptr_t errcode);
-  extern int outcome_status_code_equal(const void *a, const void *b);
-  extern int outcome_status_code_equal_generic(const void *a, int errcode);
-  extern const char *outcome_status_code_message(const void *a);
+  extern OUTCOME_C_WEAK int outcome_status_code_equal(const void *a, const void *b);
+  extern OUTCOME_C_WEAK int outcome_status_code_equal_generic(const void *a, int errcode);
+  extern OUTCOME_C_WEAK const char *outcome_status_code_message(const void *a);
 
 
 #ifdef __cplusplus
@@ -186,7 +188,7 @@ extern "C"
   OUTCOME_C_NODISCARD_EXTERN_C OUTCOME_C_WEAK struct cxx_result_status_code_##ident outcome_make_result_##ident##_failure_posix(int errcode)                   \
   {                                                                                                                                                            \
     struct cxx_result_status_code_##ident ret;                                                                                                                 \
-    assert(outcome_make_result_status_code_failure_posix); /* If this fails, you need to compile this file at least once in C++. */                            \
+    assert(outcome_make_result_status_code_failure_posix!=NULL); /* If this fails, you need to compile this file at least once in C++. */                            \
     outcome_make_result_status_code_failure_posix((void *) &ret, sizeof(ret), offsetof(struct cxx_result_status_code_##ident, flags), errcode);                \
     return ret;                                                                                                                                                \
   }                                                                                                                                                            \
@@ -194,7 +196,7 @@ extern "C"
   OUTCOME_C_NODISCARD_EXTERN_C OUTCOME_C_WEAK struct cxx_result_status_code_##ident outcome_make_result_##ident##_failure_system(intptr_t errcode)             \
   {                                                                                                                                                            \
     struct cxx_result_status_code_##ident ret;                                                                                                                 \
-    assert(outcome_make_result_status_code_failure_system); /* If this fails, you need to compile this file at least once in C++. */                           \
+    assert(outcome_make_result_status_code_failure_system!=NULL); /* If this fails, you need to compile this file at least once in C++. */                           \
     outcome_make_result_status_code_failure_system((void *) &ret, sizeof(ret), offsetof(struct cxx_result_status_code_##ident, flags), errcode);               \
     return ret;                                                                                                                                                \
   }                                                                                                                                                            \
