@@ -6,6 +6,7 @@
 #include "pool.h"
 #include "remotecache.h"
 #include "sizeclasstable.h"
+#include "snmalloc/stl/new.h"
 #include "ticker.h"
 
 namespace snmalloc
@@ -33,7 +34,7 @@ namespace snmalloc
    *   `init_message_queue`.
    */
   template<SNMALLOC_CONCEPT(IsConfigLazy) Config>
-  class CoreAllocator : public std::conditional_t<
+  class CoreAllocator : public stl::conditional_t<
                           Config::Options.CoreAllocIsPoolAllocated,
                           Pooled<CoreAllocator<Config>>,
                           Empty>
@@ -48,6 +49,7 @@ namespace snmalloc
      */
     using BackendSlabMetadata = typename Config::Backend::SlabMetadata;
     using PagemapEntry = typename Config::PagemapEntry;
+
     /// }@
 
     /**
@@ -77,7 +79,7 @@ namespace snmalloc
      * Message queue for allocations being returned to this
      * allocator
      */
-    std::conditional_t<
+    stl::conditional_t<
       Config::Options.IsQueueInline,
       RemoteAllocator,
       RemoteAllocator*>
@@ -94,7 +96,7 @@ namespace snmalloc
      * core allocator owns the local state or indirect if it is owned
      * externally.
      */
-    std::conditional_t<
+    stl::conditional_t<
       Config::Options.CoreAllocOwnsLocalState,
       LocalState,
       LocalState*>
@@ -197,6 +199,7 @@ namespace snmalloc
         {
           capptr::AllocFull<PreAllocObject> next;
         };
+
         // The following code implements Sattolo's algorithm for generating
         // random cyclic permutations.  This implementation is in the opposite
         // direction, so that the original space does not need initialising.
@@ -219,7 +222,7 @@ namespace snmalloc
                pointer_offset(curr, rsize).template as_static<PreAllocObject>())
         {
           size_t insert_index = entropy.sample(count);
-          curr->next = std::exchange(
+          curr->next = stl::exchange(
             pointer_offset(bumpptr, insert_index * rsize)
               .template as_static<PreAllocObject>()
               ->next,
@@ -508,17 +511,18 @@ namespace snmalloc
     handle_message_queue_inner(Action action, Args... args)
     {
       bool need_post = false;
+      size_t bytes_freed = 0;
       auto local_state = backend_state_ptr();
       auto domesticate = [local_state](freelist::QueuePtr p)
                            SNMALLOC_FAST_PATH_LAMBDA {
                              return capptr_domesticate<Config>(local_state, p);
                            };
-      auto cb = [this, domesticate, &need_post](
+      auto cb = [this, domesticate, &need_post, &bytes_freed](
                   capptr::Alloc<RemoteMessage> msg) SNMALLOC_FAST_PATH_LAMBDA {
         auto& entry =
-          Config::Backend::template get_metaentry(snmalloc::address_cast(msg));
-        handle_dealloc_remote(entry, msg, need_post, domesticate);
-        return true;
+          Config::Backend::get_metaentry(snmalloc::address_cast(msg));
+        handle_dealloc_remote(entry, msg, need_post, domesticate, bytes_freed);
+        return bytes_freed < REMOTE_BATCH_LIMIT;
       };
 
 #ifdef SNMALLOC_TRACING
@@ -561,7 +565,8 @@ namespace snmalloc
       const PagemapEntry& entry,
       capptr::Alloc<RemoteMessage> msg,
       bool& need_post,
-      Domesticator_queue domesticate)
+      Domesticator_queue domesticate,
+      size_t& bytes_returned)
     {
       // TODO this needs to not double count stats
       // TODO this needs to not double revoke if using MTE
@@ -571,8 +576,8 @@ namespace snmalloc
       {
         auto meta = entry.get_slab_metadata();
 
-        auto unreturned =
-          dealloc_local_objects_fast(msg, entry, meta, entropy, domesticate);
+        auto unreturned = dealloc_local_objects_fast(
+          msg, entry, meta, entropy, domesticate, bytes_returned);
 
         /*
          * dealloc_local_objects_fast has updated the free list but not updated
@@ -659,7 +664,7 @@ namespace snmalloc
      */
     template<
       typename Config_ = Config,
-      typename = std::enable_if_t<Config_::Options.CoreAllocOwnsLocalState>>
+      typename = stl::enable_if_t<Config_::Options.CoreAllocOwnsLocalState>>
     CoreAllocator(Range<capptr::bounds::Alloc>& spare)
     {
       init(spare);
@@ -674,7 +679,7 @@ namespace snmalloc
      */
     template<
       typename Config_ = Config,
-      typename = std::enable_if_t<!Config_::Options.CoreAllocOwnsLocalState>>
+      typename = stl::enable_if_t<!Config_::Options.CoreAllocOwnsLocalState>>
     CoreAllocator(
       Range<capptr::bounds::Alloc>& spare,
       LocalCache<Config_>* cache,
@@ -689,7 +694,7 @@ namespace snmalloc
      * configure the message queue for use.
      */
     template<bool InlineQueue = Config::Options.IsQueueInline>
-    std::enable_if_t<!InlineQueue> init_message_queue(RemoteAllocator* q)
+    stl::enable_if_t<!InlineQueue> init_message_queue(RemoteAllocator* q)
     {
       remote_alloc = q;
       init_message_queue();
@@ -744,7 +749,7 @@ namespace snmalloc
       // PagemapEntry-s seen here are expected to have meaningful Remote
       // pointers
       dealloc_local_object(
-        p, Config::Backend::template get_metaentry(snmalloc::address_cast(p)));
+        p, Config::Backend::get_metaentry(snmalloc::address_cast(p)));
     }
 
     SNMALLOC_FAST_PATH static bool dealloc_local_object_fast(
@@ -775,7 +780,8 @@ namespace snmalloc
       const PagemapEntry& entry,
       BackendSlabMetadata* meta,
       LocalEntropy& entropy,
-      Domesticator domesticate)
+      Domesticator domesticate,
+      size_t& bytes_freed)
     {
       SNMALLOC_ASSERT(!meta->is_unused());
 
@@ -793,6 +799,8 @@ namespace snmalloc
         meta->as_key_tweak(),
         domesticate);
 
+      bytes_freed = objsize * length;
+
       // Update the head and the next pointer in the free list.
       meta->free_queue.append_segment(
         curr,
@@ -938,14 +946,18 @@ namespace snmalloc
                              return capptr_domesticate<Config>(local_state, p);
                            };
 
+      size_t bytes_flushed = 0; // Not currently used.
+
       if (destroy_queue)
       {
-        auto cb = [this, domesticate](capptr::Alloc<RemoteMessage> m) {
-          bool need_post = true; // Always going to post, so ignore.
-          const PagemapEntry& entry =
-            Config::Backend::get_metaentry(snmalloc::address_cast(m));
-          handle_dealloc_remote(entry, m, need_post, domesticate);
-        };
+        auto cb =
+          [this, domesticate, &bytes_flushed](capptr::Alloc<RemoteMessage> m) {
+            bool need_post = true; // Always going to post, so ignore.
+            const PagemapEntry& entry =
+              Config::Backend::get_metaentry(snmalloc::address_cast(m));
+            handle_dealloc_remote(
+              entry, m, need_post, domesticate, bytes_flushed);
+          };
 
         message_queue().destroy_and_iterate(domesticate, cb);
       }
@@ -1117,7 +1129,8 @@ namespace snmalloc
       capptr::Alloc<void> spare_start = pointer_offset(raw, round_sizeof);
       Range<capptr::bounds::Alloc> r{spare_start, spare};
 
-      auto p = capptr::Alloc<CA>::unsafe_from(new (raw.unsafe_ptr()) CA(r));
+      auto p = capptr::Alloc<CA>::unsafe_from(
+        new (raw.unsafe_ptr(), placement_token) CA(r));
 
       // Remove excess from the bounds.
       p = Aal::capptr_bound<CA, capptr::bounds::Alloc>(p, round_sizeof);
