@@ -10,8 +10,8 @@ namespace vo
 class ContextFree
 {
 public:
-  halp_meta(name, "Context-Free")
-  halp_meta(category, "Visuals")
+  halp_meta(name, "Context-Free Art")
+  halp_meta(category, "Visuals/Textures")
   halp_meta(c_name, "contextfree")
   halp_meta(author, "Context-Free Art authors, Jean-Michaël Celerier")
   halp_meta(manual_url, "https://ossia.io/score-docs/processes/context-free-art.html")
