@@ -7,6 +7,7 @@
 #include <dlfcn.h>
 #endif
 
+#include <QFile>
 namespace Ndi
 {
 
@@ -53,8 +54,40 @@ Loader::Loader()
     ossia::logger().error("Error while loading NDI. Please reinstall an NDI library.");
     return;
   }
-#else
+#elif defined(__APPLE__)
+  if(ndi_folder)
+    ndi_path = ndi_folder + "/libndi.dylib"s;
+  else if(QFile::exists("/usr/local/lib/libndi.dylib"))
+    ndi_path = "/usr/local/lib/libndi.dylib";
+  else
+    ndi_path = "libndi.dylib";
 
+  m_ndi_dll = dlopen(ndi_path.c_str(), RTLD_LOCAL | RTLD_LAZY);
+  if(!m_ndi_dll)
+  {
+    ossia::logger().error(
+        "No NDI library found on the system.\nPlease install an NDI library, for "
+        "instance https://code.videolan.org/jbk/libndi");
+    return;
+  }
+
+  const NDIlib_v5* (*NDIlib_v5_load)(void) = NULL;
+  if(m_ndi_dll)
+  {
+    *((void**)&NDIlib_v5_load) = dlsym(m_ndi_dll, "NDIlib_v5_load");
+  }
+
+  if(!NDIlib_v5_load)
+  {
+    dlclose(m_ndi_dll);
+    m_ndi_dll = nullptr;
+
+    ossia::logger().error(
+        "No NDI library found on the system.\nPlease install an NDI library, for "
+        "instance https://code.videolan.org/jbk/libndi");
+    return;
+  }
+#else
   for(auto ndi_name : {"libndi.so.8", "libndi.so.7", "libndi.so.6", "libndi.so.5"})
   {
     if(ndi_folder)
@@ -69,6 +102,19 @@ Loader::Loader()
     }
   }
 
+  if(!m_ndi_dll)
+  {
+    for(auto ndi_name :
+        {"libndi.so.8", "libndi.so.7", "libndi.so.6", "libndi.so.5", "libndi.so"})
+    {
+      if((m_ndi_dll = dlopen(ndi_name, RTLD_LOCAL | RTLD_LAZY)))
+      {
+        ossia::logger().info("Found NDI: {}", ndi_path);
+        break;
+      }
+    }
+  }
+
   if(!m_ndi_dll)
   {
     ossia::logger().error(
@@ -94,6 +140,7 @@ Loader::Loader()
     return;
   }
 #endif
+
   m_lib = NDIlib_v5_load();
   if(m_lib)
   {
