@@ -16,12 +16,15 @@ TRTPoseDetector::TRTPoseDetector() noexcept
 TRTPoseDetector::~TRTPoseDetector() = default;
 
 void TRTPoseDetector::operator()()
+try
 {
 #if 0
   qDebug("============ BEGIN FRAME");
 #endif
   if (!available)
     return;
+  if (current_model_invalid)
+    return;
 
   auto& in_tex = inputs.image.texture;
 
@@ -317,4 +320,8 @@ void TRTPoseDetector::operator()()
 
   std::swap(storage, t.storage);
 }
+catch (...)
+{
+  current_model_invalid = true;
+}
 }
