@@ -14,3 +14,5 @@
 #include <puara/descriptors/roll.h>
 #include <puara/descriptors/shake.h>
 #include <puara/descriptors/tilt.h>
+#include <puara/descriptors/simple_tilt_roll.h>
+#include <puara/descriptors/touchArrayGestureDetector.h>
