@@ -20,6 +20,11 @@ struct Coord3D
   double x, y, z;
 };
 
+struct Simple_Orientation
+{
+  double roll, tilt, magnitude;
+};
+
 struct Spherical
 {
   double azimuth;
