@@ -11,6 +11,7 @@ class QLineEdit;
 class QSpinBox;
 class QTableWidget;
 class QPushButton;
+class QComboBox;
 
 namespace SpatGRIS
 {
@@ -28,6 +29,9 @@ private:
   QLineEdit* m_deviceNameEdit{};
   QLineEdit* m_host{};
   QSpinBox* m_port{};
+  QSpinBox* m_inputPort{};
   QSpinBox* m_control{};
+  QComboBox* m_format{};
+  QSpinBox* m_programs{};
 };
 }
