@@ -17,19 +17,20 @@ class SCORE_LIB_BASE_EXPORT QGraphicsXYChooser final
     , public QGraphicsItem
 {
   W_OBJECT(QGraphicsXYChooser)
-  Q_INTERFACES(QGraphicsItem)
+  SCORE_GRAPHICS_ITEM_TYPE(250)
   QRectF m_rect{0., 0., 100., 100.};
 
 private:
-  ossia::vec2f m_value{}, m_min{}, m_max{};
+  ossia::vec2f m_value{}, m_min{}, m_max{}, m_init{};
   bool m_grab{};
 
 public:
-  QGraphicsXYChooser(QGraphicsItem* parent);
+  explicit QGraphicsXYChooser(QGraphicsItem* parent);
+  ~QGraphicsXYChooser();
 
   void setPoint(const QPointF& r);
   void setValue(ossia::vec2f v);
-  void setRange(ossia::vec2f min, ossia::vec2f max);
+  void setRange(ossia::vec2f min, ossia::vec2f max, ossia::vec2f init);
   ossia::vec2f value() const;
 
   bool moving = false;
