@@ -1,6 +1,8 @@
 #pragma once
 #include <score/tools/opaque/OpaqueString.hpp>
 
+#include <ossia/detail/hash.hpp>
+
 #include <score_lib_base_export.h>
 // TODO rename file.
 template <typename Tag>
@@ -9,7 +11,7 @@ class StringKey : OpaqueString
 public:
   using this_type = StringKey<Tag>;
 
-  friend struct std::hash<this_type>;
+  friend struct ossia::hash<this_type>;
   friend bool operator==(const StringKey& lhs, const StringKey& rhs) noexcept
   {
     return static_cast<const OpaqueString&>(lhs)
@@ -38,7 +40,7 @@ struct hash<StringKey<T>>
 {
   std::size_t operator()(const StringKey<T>& kagi) const noexcept
   {
-    return std::hash<std::string>()(kagi.toString());
+    return ossia::hash<std::string>()(kagi.toString());
   }
 };
 }
