@@ -84,20 +84,20 @@ struct TSerializer<JSONObject, std::unordered_map<T, U, H, E, A>> : MapSerialize
 #if !defined(OSSIA_NO_FAST_CONTAINERS)
 template <
     class Key, class T, class Hash, class KeyEqual, class AllocatorOrContainer,
-    class Bucket, bool IsSegmented>
+    class Bucket, class BC, bool IsSegmented>
 struct TSerializer<
     DataStream, ankerl::unordered_dense::detail::table<
-                    Key, T, Hash, KeyEqual, AllocatorOrContainer, Bucket, IsSegmented>>
+                    Key, T, Hash, KeyEqual, AllocatorOrContainer, Bucket, BC, IsSegmented>>
     : MapSerializer
 {
 };
 
 template <
     class Key, class T, class Hash, class KeyEqual, class AllocatorOrContainer,
-    class Bucket, bool IsSegmented>
+    class Bucket, class BC, bool IsSegmented>
 struct TSerializer<
     JSONObject, ankerl::unordered_dense::detail::table<
-                    Key, T, Hash, KeyEqual, AllocatorOrContainer, Bucket, IsSegmented>>
+                    Key, T, Hash, KeyEqual, AllocatorOrContainer, Bucket, BC, IsSegmented>>
     : MapSerializer
 {
 };
