@@ -13,16 +13,16 @@ const QMap<ossia::bounding_mode, QString> clipmodemap{{
     {ossia::bounding_mode::CLIP, QStringLiteral("Clip")},
     {ossia::bounding_mode::FOLD, QStringLiteral("Fold")},
     {ossia::bounding_mode::WRAP, QStringLiteral("Wrap")},
-    {ossia::bounding_mode::LOW, QStringLiteral("Low")},
-    {ossia::bounding_mode::HIGH, QStringLiteral("High")},
+    {ossia::bounding_mode::CLAMP_LOW, QStringLiteral("Low")},
+    {ossia::bounding_mode::CLAMP_HIGH, QStringLiteral("High")},
 }};
 const QMap<ossia::bounding_mode, QString> clipmodeprettymap{{
     {ossia::bounding_mode::FREE, QObject::tr("Free")},
     {ossia::bounding_mode::CLIP, QObject::tr("Clip")},
     {ossia::bounding_mode::FOLD, QObject::tr("Fold")},
     {ossia::bounding_mode::WRAP, QObject::tr("Wrap")},
-    {ossia::bounding_mode::LOW, QObject::tr("Low")},
-    {ossia::bounding_mode::HIGH, QObject::tr("High")},
+    {ossia::bounding_mode::CLAMP_LOW, QObject::tr("Low")},
+    {ossia::bounding_mode::CLAMP_HIGH, QObject::tr("High")},
 }};
 const QMap<ossia::bounding_mode, QString>& ClipModeStringMap()
 {
