@@ -6,15 +6,23 @@ MoveNodes::MoveNodes(std::vector<const ProcessModel*> processes, QPointF delta)
     : m_delta{delta}
 {
   for(auto& proc : processes)
+  {
     m_models.emplace_back(Path{*proc}, proc->position());
+  }
 }
 
 void MoveNodes::undo(const score::DocumentContext& ctx) const
 {
   for(auto& [path, orig_pos] : m_models)
   {
-    auto& proc = path.find(ctx);
-    proc.setPosition(orig_pos);
+    if(auto* proc = path.try_find(ctx))
+    {
+      proc->setPosition(orig_pos);
+    }
+    else
+    {
+      qDebug() << "Warning! trying to move a destroyed node";
+    }
   }
 }
 
@@ -22,8 +30,14 @@ void MoveNodes::redo(const score::DocumentContext& ctx) const
 {
   for(auto& [path, orig_pos] : m_models)
   {
-    auto& proc = path.find(ctx);
-    proc.setPosition(orig_pos + m_delta);
+    if(auto* proc = path.try_find(ctx))
+    {
+      proc->setPosition(orig_pos + m_delta);
+    }
+    else
+    {
+      qDebug() << "Warning! trying to move a destroyed node";
+    }
   }
 }
 
