@@ -50,7 +50,7 @@ struct GfxRenderer<Node_T> final : score::gfx::OutputNodeRenderer
     static constexpr auto flags
         = QRhiTexture::RenderTarget | QRhiTexture::UsedAsTransferSource;
     auto texture = renderer.state.rhi->newTexture(
-        gpp::qrhi::textureFormat<Tex>(), spec.size, 1, flags);
+        gpp::qrhi::textureFormat(texture_spec), spec.size, 1, flags);
     SCORE_ASSERT(texture->create());
     m_rts[port] = score::gfx::createRenderTarget(
         renderer.state, texture, renderer.samples(), renderer.requiresDepth());
@@ -292,8 +292,8 @@ struct GfxNode<Node_T> final
   oscr::ProcessModel<Node_T>& processModel;
   GfxNode(
       oscr::ProcessModel<Node_T>& element,
-      std::weak_ptr<Execution::ExecutionCommandQueue> q, Gfx::exec_controls ctls, int id,
-      const score::DocumentContext& ctx)
+      std::weak_ptr<Execution::ExecutionCommandQueue> q, Gfx::exec_controls ctls,
+      int64_t id, const score::DocumentContext& ctx)
       : CustomGpuOutputNodeBase{std::move(q), std::move(ctls), ctx}
       , processModel{element}
   {
