@@ -28,8 +28,8 @@ template <typename Node_T>
 struct GpuComputeNode final : ComputeNodeBaseType<Node_T>
 {
   GpuComputeNode(
-      std::weak_ptr<Execution::ExecutionCommandQueue> q, Gfx::exec_controls ctls, int id,
-      const score::DocumentContext& ctx)
+      std::weak_ptr<Execution::ExecutionCommandQueue> q, Gfx::exec_controls ctls,
+      int64_t id, const score::DocumentContext& ctx)
       : ComputeNodeBaseType<Node_T>{std::move(q), std::move(ctls), ctx}
   {
     this->instance = id;
@@ -349,9 +349,9 @@ struct GpuComputeRenderer final : ComputeRendererBaseType<Node_T>
       state->release();
     }
 
-    // Release the allocated textures
-    for(auto& [id, tex] : this->createdTexs)
-      tex->deleteLater();
+    // Allocated textures are all inside RTs which are released a little bit later.
+    // for(auto& [id, tex] : this->createdTexs)
+    //   tex->deleteLater();
     this->createdTexs.clear();
 
     // Release the allocated ubos
