@@ -31,8 +31,150 @@
 
 namespace gpp::qrhi
 {
+
 template <typename F>
-constexpr QRhiTexture::Format textureFormat()
+  requires std::is_enum_v<F>
+constexpr QRhiTexture::Format textureFormat(F f) noexcept
+{
+  if constexpr(requires { F::RGBA; } || requires { F::RGBA8; })
+    if(f == F::RGBA8)
+      return QRhiTexture::RGBA8;
+  if constexpr(requires { F::BGRA; } || requires { F::BGRA8; })
+    if(f == F::BGRA8)
+      return QRhiTexture::BGRA8;
+  if constexpr(requires { F::R8; } || requires { F::GRAYSCALE; })
+    if(f == F::R8)
+      return QRhiTexture::R8;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+  if constexpr(requires { F::RG8; })
+    if(f == F::RG8)
+      return QRhiTexture::RG8;
+#endif
+  if constexpr(requires { F::R16; })
+    if(f == F::R16)
+      return QRhiTexture::R16;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+  if constexpr(requires { F::RG16; })
+    if(f == F::RG16)
+      return QRhiTexture::RG16;
+#endif
+  if constexpr(requires { F::RED_OR_ALPHA8; })
+    if(f == F::RED_OR_ALPHA8)
+      return QRhiTexture::RED_OR_ALPHA8;
+  if constexpr(requires { F::RGBA16F; })
+    if(f == F::RGBA16F)
+      return QRhiTexture::RGBA16F;
+  if constexpr(requires { F::RGBA32F; })
+    if(f == F::RGBA32F)
+      return QRhiTexture::RGBA32F;
+  if constexpr(requires { F::R16F; })
+    if(f == F::R16F)
+      return QRhiTexture::R16F;
+  if constexpr(requires { F::R32F; })
+    if(f == F::R32F)
+      return QRhiTexture::R32F;
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+  if constexpr(requires { F::RGB10A2; })
+    if(f == F::RGB10A2)
+      return QRhiTexture::RGB10A2;
+#endif
+  if constexpr(requires { F::D16; })
+    if(f == F::D16)
+      return QRhiTexture::D16;
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
+  if constexpr(requires { F::D24; })
+    if(f == F::D24)
+      return QRhiTexture::D24;
+  if constexpr(requires { F::D24S8; })
+    if(f == F::D24S8)
+      return QRhiTexture::D24S8;
+#endif
+  if constexpr(requires { F::D32F; })
+    if(f == F::D32F)
+      return QRhiTexture::D32F;
+
+  if constexpr(requires { F::BC1; })
+    if(f == F::BC1)
+      return QRhiTexture::BC1;
+  if constexpr(requires { F::BC2; })
+    if(f == F::BC2)
+      return QRhiTexture::BC2;
+  if constexpr(requires { F::BC3; })
+    if(f == F::BC3)
+      return QRhiTexture::BC3;
+  if constexpr(requires { F::BC4; })
+    if(f == F::BC4)
+      return QRhiTexture::BC4;
+  if constexpr(requires { F::BC5; })
+    if(f == F::BC5)
+      return QRhiTexture::BC5;
+  if constexpr(requires { F::BC6H; })
+    if(f == F::BC6H)
+      return QRhiTexture::BC6H;
+  if constexpr(requires { F::BC7; })
+    if(f == F::BC7)
+      return QRhiTexture::BC7;
+  if constexpr(requires { F::ETC2_RGB8; })
+    if(f == F::ETC2_RGB8)
+      return QRhiTexture::ETC2_RGB8;
+  if constexpr(requires { F::ETC2_RGB8A1; })
+    if(f == F::ETC2_RGB8A1)
+      return QRhiTexture::ETC2_RGB8A1;
+  if constexpr(requires { F::ETC2_RGB8A8; })
+    if(f == F::ETC2_RGBA8)
+      return QRhiTexture::ETC2_RGBA8;
+  if constexpr(requires { F::ASTC_4X4; })
+    if(f == F::ASTC_4x4)
+      return QRhiTexture::ASTC_4x4;
+  if constexpr(requires { F::ASTC_5X4; })
+    if(f == F::ASTC_5x4)
+      return QRhiTexture::ASTC_5x4;
+  if constexpr(requires { F::ASTC_5X5; })
+    if(f == F::ASTC_5x5)
+      return QRhiTexture::ASTC_5x5;
+  if constexpr(requires { F::ASTC_6X5; })
+    if(f == F::ASTC_6x5)
+      return QRhiTexture::ASTC_6x5;
+  if constexpr(requires { F::ASTC_6X6; })
+    if(f == F::ASTC_6x6)
+      return QRhiTexture::ASTC_6x6;
+  if constexpr(requires { F::ASTC_8X5; })
+    if(f == F::ASTC_8x5)
+      return QRhiTexture::ASTC_8x5;
+  if constexpr(requires { F::ASTC_8X6; })
+    if(f == F::ASTC_8x6)
+      return QRhiTexture::ASTC_8x6;
+  if constexpr(requires { F::ASTC_8X8; })
+    if(f == F::ASTC_8x8)
+      return QRhiTexture::ASTC_8x8;
+  if constexpr(requires { F::ASTC_10X5; })
+    if(f == F::ASTC_10x5)
+      return QRhiTexture::ASTC_10x5;
+  if constexpr(requires { F::ASTC_10X6; })
+    if(f == F::ASTC_10x6)
+      return QRhiTexture::ASTC_10x6;
+  if constexpr(requires { F::ASTC_10X8; })
+    if(f == F::ASTC_10x8)
+      return QRhiTexture::ASTC_10x8;
+  if constexpr(requires { F::ASTC_10X10; })
+    if(f == F::ASTC_10x10)
+      return QRhiTexture::ASTC_10x10;
+  if constexpr(requires { F::ASTC_12X10; })
+    if(f == F::ASTC_12x10)
+      return QRhiTexture::ASTC_12x10;
+  if constexpr(requires { F::ASTC_12X12; })
+    if(f == F::ASTC_12x12)
+      return QRhiTexture::ASTC_12x12;
+  if constexpr(requires { F::RGB; })
+    if(f == F::RGB)
+      return QRhiTexture::RGBA8; // we'll have a CPU step to go to rgb
+
+  return QRhiTexture::RGBA8;
+}
+
+template <typename F>
+constexpr QRhiTexture::Format textureFormat() noexcept
 {
   if constexpr(requires { std::string_view{F::format()}; })
   {
@@ -129,6 +271,8 @@ constexpr QRhiTexture::Format textureFormat()
     return QRhiTexture::ASTC_12x10;
   else if(fmt == "astc_12x12")
     return QRhiTexture::ASTC_12x12;
+  else if(fmt == "rgb")
+    return QRhiTexture::RGBA8;
   else
     return QRhiTexture::RGBA8;
   }
@@ -190,45 +334,58 @@ constexpr QRhiTexture::Format textureFormat()
       return QRhiTexture::BC6H;
     else if constexpr(requires { F::BC7; })
       return QRhiTexture::BC7;
-    else if(requires { F::ETC2_RGB8; })
+    else if constexpr(requires { F::ETC2_RGB8; })
       return QRhiTexture::ETC2_RGB8;
-    else if(requires { F::ETC2_RGB8A1; })
+    else if constexpr(requires { F::ETC2_RGB8A1; })
       return QRhiTexture::ETC2_RGB8A1;
-    else if(requires { F::ETC2_RGB8A8; })
+    else if constexpr(requires { F::ETC2_RGB8A8; })
       return QRhiTexture::ETC2_RGBA8;
-    else if(requires { F::ASTC_4X4; })
+    else if constexpr(requires { F::ASTC_4X4; })
       return QRhiTexture::ASTC_4x4;
-    else if(requires { F::ASTC_5X4; })
+    else if constexpr(requires { F::ASTC_5X4; })
       return QRhiTexture::ASTC_5x4;
-    else if(requires { F::ASTC_5X5; })
+    else if constexpr(requires { F::ASTC_5X5; })
       return QRhiTexture::ASTC_5x5;
-    else if(requires { F::ASTC_6X5; })
+    else if constexpr(requires { F::ASTC_6X5; })
       return QRhiTexture::ASTC_6x5;
-    else if(requires { F::ASTC_6X6; })
+    else if constexpr(requires { F::ASTC_6X6; })
       return QRhiTexture::ASTC_6x6;
-    else if(requires { F::ASTC_8X5; })
+    else if constexpr(requires { F::ASTC_8X5; })
       return QRhiTexture::ASTC_8x5;
-    else if(requires { F::ASTC_8X6; })
+    else if constexpr(requires { F::ASTC_8X6; })
       return QRhiTexture::ASTC_8x6;
-    else if(requires { F::ASTC_8X8; })
+    else if constexpr(requires { F::ASTC_8X8; })
       return QRhiTexture::ASTC_8x8;
-    else if(requires { F::ASTC_10X5; })
+    else if constexpr(requires { F::ASTC_10X5; })
       return QRhiTexture::ASTC_10x5;
-    else if(requires { F::ASTC_10X6; })
+    else if constexpr(requires { F::ASTC_10X6; })
       return QRhiTexture::ASTC_10x6;
-    else if(requires { F::ASTC_10X8; })
+    else if constexpr(requires { F::ASTC_10X8; })
       return QRhiTexture::ASTC_10x8;
-    else if(requires { F::ASTC_10X10; })
+    else if constexpr(requires { F::ASTC_10X10; })
       return QRhiTexture::ASTC_10x10;
-    else if(requires { F::ASTC_12X10; })
+    else if constexpr(requires { F::ASTC_12X10; })
       return QRhiTexture::ASTC_12x10;
-    else if(requires { F::ASTC_12X12; })
+    else if constexpr(requires { F::ASTC_12X12; })
       return QRhiTexture::ASTC_12x12;
+    else if constexpr(requires { F::RGB; })
+      return QRhiTexture::RGBA8;
     else
       return QRhiTexture::RGBA8;
   }
 }
 
+template <avnd::cpu_texture Tex>
+constexpr QRhiTexture::Format textureFormat(const Tex& t) noexcept
+{
+  QRhiTexture::Format fmt{};
+  if constexpr(avnd::cpu_dynamic_format_texture<Tex>)
+    fmt = gpp::qrhi::textureFormat(t.format);
+  else
+    fmt = gpp::qrhi::textureFormat<Tex>();
+  return fmt;
+}
+
 struct DefaultPipeline
 {
   struct layout
@@ -984,7 +1141,7 @@ struct GpuControlOuts
   std::weak_ptr<Execution::ExecutionCommandQueue> queue;
   Gfx::exec_controls control_outs;
 
-  int instance{};
+  int64_t instance{};
 
   template <typename Node_T>
   void processControlOut(Node_T& state) const noexcept
@@ -1123,12 +1280,12 @@ void prepareNewState(std::shared_ptr<Node_T>& eff, const Node& parent)
   if constexpr(avnd::has_processor_to_gui_bus<Node_T>)
   {
     auto& process = parent.processModel;
-    eff->send_message = [&process](auto&& b) mutable {
+    eff->send_message = [ptr = QPointer{&process}](auto&& b) mutable {
       // FIXME right now all the rendering is done in the UI thread, which is very MEH
       //    this->in_edit([&process, bb = std::move(b)]() mutable {
 
-      if(process.to_ui)
-        MessageBusSender{process.to_ui}(std::move(b));
+      if(ptr && ptr->to_ui)
+        MessageBusSender{ptr->to_ui}(std::move(b));
       //    });
     };
 
