@@ -12,10 +12,89 @@
 #include <QApplication>
 #include <QTimer>
 
+#include <rnd/random.hpp>
+
 namespace Gfx
 {
 namespace
 {
+// Basic "synth" to generate a fake waveform for audio reactive shader previews
+class FakeMusicGenerator
+{
+private:
+  double bassPhase = 0.0;
+  float kickEnv = 0.0f;
+  float snareEnv = 0.0f;
+  float bassEnv = 0.0f;
+  int sampleCounter = 0;
+
+  float last{};
+
+public:
+  void operator()(float* buffer, size_t numSamples)
+  {
+    const float FS = 48000.;
+    const double twoPi = 2.0 * M_PI;
+    const double bassFreq = rnd::rand(1000., 5000.);
+    const double bassInc = twoPi * bassFreq / FS;
+    const int samplesPerBeat = FS / 2;
+
+    for(size_t i = 0; i < numSamples; i++)
+    {
+      if(sampleCounter % samplesPerBeat == 0)
+        kickEnv = 1.0f;
+      if(sampleCounter % samplesPerBeat == samplesPerBeat / 2)
+        snareEnv = 0.8f;
+      if(sampleCounter % samplesPerBeat == samplesPerBeat / 3)
+        bassEnv = 0.5f;
+
+      float bass = 0.f;
+      if(bassEnv > 0.01f)
+      {
+        bass += (std::sin(bassPhase)
+                 + std::sin(bassPhase) * std::sin(std::sin(bassPhase)))
+                * std::pow(bassEnv, 2.f) * 0.1f;
+        bassEnv *= 0.9995f;
+      }
+
+      float kick = 0.0f;
+      if(kickEnv > 0.01f)
+      {
+        float kickPitch = 100.0 + kickEnv * 30.0;
+        kick = std::sin(twoPi * kickPitch * sampleCounter / FS) * kickEnv * 0.5f;
+        kickEnv *= 0.9f;
+      }
+
+      float snare = 0.0f;
+      if(snareEnv > 0.01f)
+      {
+        snare = rnd::rand(-1., 1.) * snareEnv * 0.3f;
+        snareEnv *= 0.9f;
+      }
+
+      float hihat = 0.0;
+      if((sampleCounter % (samplesPerBeat / 4)) < 10)
+      {
+        hihat = rnd::rand(-1., 1.);
+      }
+
+      float sample = kick + snare + bass + hihat;
+      sample = (0.005 * sample) + (1. - 0.005) * this->last;
+      last = sample;
+
+      sample = std::tanh(sample * 0.5f);
+
+      buffer[i] = sample;
+
+      bassPhase += bassInc;
+
+      if(bassPhase > twoPi)
+        bassPhase -= twoPi;
+      sampleCounter++;
+    }
+  }
+};
+
 struct PreviewInputVisitor
 {
   int& img_count;
@@ -52,6 +131,41 @@ struct PreviewInputVisitor
   score::gfx::NodeModel* operator()(const isf::audio_input& v) { return nullptr; }
 
   score::gfx::NodeModel* operator()(const isf::audioFFT_input& v) { return nullptr; }
+
+  score::gfx::NodeModel* operator()(const isf::audioHist_input& v) { return nullptr; }
+  
+  // CSF-specific input handlers
+  score::gfx::NodeModel* operator()(const isf::storage_input& v) { return nullptr; }
+  
+  score::gfx::NodeModel* operator()(const isf::texture_input& v)
+  {
+    static std::array<QImage, 3> images{
+        QImage{":/gfx/testcard-1.png"}.scaled(
+            300, 200, Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation),
+        QImage{":/gfx/testcard-2.jpeg"}.scaled(
+            300, 200, Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation),
+        QImage{":/gfx/testcard-3.png"}.scaled(
+            300, 200, Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation)};
+    auto image_node = new score::gfx::FullScreenImageNode{images[img_count]};
+    img_count++;
+    img_count = img_count % 3;
+    return image_node;
+  }
+  
+  score::gfx::NodeModel* operator()(const isf::csf_image_input& v)
+  {
+    static std::array<QImage, 3> images{
+        QImage{":/gfx/testcard-1.png"}.scaled(
+            300, 200, Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation),
+        QImage{":/gfx/testcard-2.jpeg"}.scaled(
+            300, 200, Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation),
+        QImage{":/gfx/testcard-3.png"}.scaled(
+            300, 200, Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation)};
+    auto image_node = new score::gfx::FullScreenImageNode{images[img_count]};
+    img_count++;
+    img_count = img_count % 3;
+    return image_node;
+  }
 };
 
 struct PreviewPresetVisitor
@@ -120,6 +234,15 @@ struct PreviewPresetVisitor
   void operator()(const isf::audio_input& v) { }
 
   void operator()(const isf::audioFFT_input& v) { }
+
+  void operator()(const isf::audioHist_input& v) { }
+  
+  // CSF-specific input handlers
+  void operator()(const isf::storage_input& v) { }
+  
+  void operator()(const isf::texture_input& v) { }
+  
+  void operator()(const isf::csf_image_input& v) { }
 };
 }
 
@@ -146,7 +269,11 @@ public:
 
   void load(const QString& path)
   {
-    ShaderSource program = programFromFragmentShaderPath(path, {});
+    ShaderSource program;
+    if(path.contains(".fs") || path.contains(".frag"))
+      program = programFromISFFragmentShaderPath(path, {});
+    if(path.contains(".vs") || path.contains(".vert"))
+      program = programFromVSAVertexShaderPath(path, {});
 
     if(const auto& [processed, error] = ProgramCache::instance().get(program);
        bool(processed))
@@ -164,9 +291,12 @@ public:
     auto obj = doc.GetObject();
     if(!obj.HasMember("Fragment") || !obj.HasMember("Vertex"))
       return;
+    ShaderSource::ProgramType type = ShaderSource::ProgramType::ISF;
+    if(obj.HasMember("Type"))
+      type = (ShaderSource::ProgramType)obj["Type"].GetInt();
     auto frag = obj["Fragment"].GetString();
     auto vert = obj["Vertex"].GetString();
-    ShaderSource program{vert, frag};
+    ShaderSource program{type, vert, frag};
 
     if(const auto& [processed, error] = ProgramCache::instance().get(program);
        bool(processed))
@@ -287,6 +417,19 @@ public:
         progress_k++;
       }
 
+      for(auto in : m_isf->input)
+      {
+        if(in->type == score::gfx::Types::Audio)
+        {
+          auto tex = (score::gfx::AudioTexture*)in->value;
+          tex->data.resize(512);
+          tex->channels = 1;
+
+          static FakeMusicGenerator generator;
+          generator(tex->data.data(), 512);
+        }
+      }
+
       if(has_progress)
       {
         if(m_isf->input.size() > progress_k)
