@@ -10,13 +10,21 @@
 #include <isf.hpp>
 
 #include <array>
+namespace Gfx
+{
+struct ISFHelpers;
+};
 namespace Gfx::Filter
 {
+
 class Model final : public Process::ProcessModel
 {
   SCORE_SERIALIZE_FRIENDS
   PROCESS_METADATA_IMPL(Gfx::Filter::Model)
   W_OBJECT(Model)
+  friend struct Gfx::ISFHelpers;
+  using Process::ProcessModel::m_inlets;
+  using Process::ProcessModel::m_outlets;
 
 public:
   static constexpr bool hasExternalUI() noexcept { return true; }
@@ -63,10 +71,6 @@ public:
 private:
   void loadPreset(const Process::Preset& preset) override;
   Process::Preset savePreset() const noexcept override;
-  void setupIsf(
-      const isf::descriptor& d,
-      const ossia::flat_map<QString, ossia::value>& previous_values);
-  //void setupNormalShader();
   QString prettyName() const noexcept override;
 
   ShaderSource m_program;
