@@ -29,15 +29,22 @@ GfxContext::GfxContext(const score::DocumentContext& ctx)
       &GfxContext::recompute_graph);
   con(settings, &Gfx::Settings::Model::RateChanged, this, &GfxContext::recompute_graph);
   con(settings, &Gfx::Settings::Model::VSyncChanged, this, &GfxContext::recompute_graph);
+  con(settings, &Gfx::Settings::Model::BuffersChanged, this,
+      &GfxContext::recompute_graph);
 
   m_graph = new score::gfx::Graph;
 
   double rate = m_context.app.settings<Gfx::Settings::Model>().getRate();
   rate = 1000. / qBound(1.0, rate, 1000.);
 
-  QMetaObject::invokeMethod(
-      this, [this, rate] { m_timer = startTimer(rate, Qt::PreciseTimer); },
-      Qt::QueuedConnection);
+  QMetaObject::invokeMethod(this, [this, rate] {
+    m_no_vsync_timer = startTimer(rate, Qt::PreciseTimer);
+  }, Qt::QueuedConnection);
+
+  // A safety timer necessary to handle graph updates in case we had vsync and lost it
+  QMetaObject::invokeMethod(this, [this] {
+    m_watchdog_timer = startTimer(50, Qt::PreciseTimer);
+  }, Qt::QueuedConnection);
 }
 
 GfxContext::~GfxContext()
@@ -82,17 +89,17 @@ void GfxContext::unregister_preview_node(int32_t idx)
   tick_commands.enqueue(NodeCommand{NodeCommand::REMOVE_PREVIEW_NODE, idx, {}});
 }
 
-void GfxContext::connect_preview_node(Edge e)
+void GfxContext::connect_preview_node(EdgeSpec e)
 {
   tick_commands.enqueue(EdgeCommand{EdgeCommand::CONNECT_PREVIEW_NODE, e});
 }
 
-void GfxContext::disconnect_preview_node(Edge e)
+void GfxContext::disconnect_preview_node(EdgeSpec e)
 {
   tick_commands.enqueue(EdgeCommand{EdgeCommand::DISCONNECT_PREVIEW_NODE, e});
 }
 
-void GfxContext::add_edge(Edge edge)
+void GfxContext::add_edge(EdgeSpec edge)
 {
   auto source_node_it = this->nodes.find(edge.first.node);
   if(source_node_it != this->nodes.end())
@@ -118,7 +125,7 @@ void GfxContext::add_edge(Edge edge)
   }
 }
 
-void GfxContext::remove_edge(Edge edge)
+void GfxContext::remove_edge(EdgeSpec edge)
 {
   auto source_node_it = this->nodes.find(edge.first.node);
   if(source_node_it != this->nodes.end())
@@ -149,19 +156,19 @@ void GfxContext::recompute_edges()
 
 void GfxContext::recompute_graph()
 {
-  if(m_timer != -1)
-    killTimer(m_timer);
+  if(m_no_vsync_timer != -1)
+    killTimer(m_no_vsync_timer);
   for(auto [id, ptr] : m_manualTimers)
     killTimer(id);
   m_manualTimers.clear();
 
-  m_timer = -1;
+  m_no_vsync_timer = -1;
   m_graph->setVSyncCallback({});
 
   recompute_edges();
 
   auto& settings = m_context.app.settings<Gfx::Settings::Model>();
-  auto api = settings.graphicsApiEnum();
+  const auto api = settings.graphicsApiEnum();
 
   m_graph->createAllRenderLists(api);
 
@@ -187,16 +194,17 @@ void GfxContext::recompute_graph()
   }
   else
   {
-    QMetaObject::invokeMethod(
-        this, [this, rate] { m_timer = startTimer(rate, Qt::PreciseTimer); },
-        Qt::QueuedConnection);
+    QMetaObject::invokeMethod(this, [this, rate] {
+      m_no_vsync_timer = startTimer(rate, Qt::PreciseTimer);
+    }, Qt::QueuedConnection);
   }
 
   // This starts the timers which control the actual render rate of various things
 
   for(auto& outputs : m_graph->renderLists())
   {
-    if(auto conf = outputs->output.configuration(); conf.manualRenderingRate)
+    auto conf = outputs->output.configuration();
+    if(conf.manualRenderingRate)
     {
       int id = startTimer(*conf.manualRenderingRate, Qt::PreciseTimer);
       m_manualTimers[id] = &outputs->output;
@@ -215,8 +223,8 @@ void GfxContext::add_preview_output(score::gfx::OutputNode& node)
   double rate = m_context.app.settings<Gfx::Settings::Model>().getRate();
   rate = 1000. / qBound(1.0, rate, 1000.);
 
-  if(m_timer == -1)
-    m_timer = startTimer(rate, Qt::PreciseTimer);
+  if(m_no_vsync_timer == -1)
+    m_no_vsync_timer = startTimer(rate, Qt::PreciseTimer);
 }
 
 void GfxContext::recompute_connections()
@@ -318,7 +326,7 @@ void GfxContext::run_commands()
           auto n = dynamic_cast<score::gfx::OutputNode*>(node.get());
           SCORE_ASSERT(n);
           {
-            auto it = ossia::find_if(this->preview_edges, [idx = cmd.index](Edge e) {
+            auto it = ossia::find_if(this->preview_edges, [idx = cmd.index](EdgeSpec e) {
               return e.second.node == idx;
             });
             if(it != this->preview_edges.end())
@@ -400,17 +408,17 @@ void GfxContext::updateGraph()
 
 void GfxContext::timerEvent(QTimerEvent* ev)
 {
-  if(ev->timerId() == m_timer)
+  const auto tid = ev->timerId();
+  if(tid == m_no_vsync_timer || tid == m_watchdog_timer)
   {
     updateGraph();
   }
   else
   {
-    if(auto ptr = m_manualTimers.find(ev->timerId()); ptr != m_manualTimers.end())
+    if(auto ptr = m_manualTimers.find(tid); ptr != m_manualTimers.end())
     {
       ptr->second->render();
     }
   }
 }
-
 }
