@@ -11,7 +11,7 @@ struct SCORE_PLUGIN_GFX_EXPORT GeometryFilterNodeRenderer : score::gfx::NodeRend
 
   TextureRenderTarget renderTargetForInput(const Port& p) override;
   void init(RenderList& renderer, QRhiResourceUpdateBatch& res) override;
-  void update(RenderList& renderer, QRhiResourceUpdateBatch& res) override;
+  void update(RenderList& renderer, QRhiResourceUpdateBatch& res, Edge* edge) override;
   void release(RenderList& r) override;
 
   void runInitialPasses(
@@ -23,11 +23,10 @@ struct SCORE_PLUGIN_GFX_EXPORT GeometryFilterNodeRenderer : score::gfx::NodeRend
   QRhiBuffer* material() const noexcept { return m_materialUBO; }
 
 private:
-  GeometryFilterNode& n;
+  GeometryFilterNode& node() const noexcept;
 
   QRhiBuffer* m_materialUBO{};
   int m_materialSize{};
-  int64_t materialChangedIndex{-1};
 };
 
 }
