@@ -20,6 +20,7 @@ class ISFNode : public score::gfx::ProcessNode
 {
 public:
   ISFNode(const isf::descriptor& desc, const QString& vert, const QString& frag);
+  ISFNode(const isf::descriptor& desc, const QString& comp);
 
   virtual ~ISFNode();
   QSize computeTextureSize(const isf::pass& pass, QSize origSize);
@@ -27,7 +28,7 @@ public:
   score::gfx::NodeRenderer* createRenderer(RenderList& r) const noexcept override;
 
   const isf::descriptor& descriptor() const noexcept { return m_descriptor; }
-
+  void process(Message&& msg) override;
   friend SinglePassISFNode;
   friend RenderedISFNode;
   friend isf_input_port_vis;
@@ -40,6 +41,9 @@ public:
 
   QString m_vertexS;
   QString m_fragmentS;
+  QString m_computeS;
+  std::vector<int*> m_event_ports;
+
   int m_materialSize{};
 };
 }
