@@ -34,11 +34,15 @@ public:
     float position[2]{0.5, 0.5};
     float scale[2]{1., 1.};
     float imageSize[2]{1., 1.};
+    float renderSize[2]{1280., 720.};
   } ubo;
 #pragma pack(pop)
 
   std::atomic_int imagesChanged{};
-  std::atomic<ImageMode> tile{};
+  std::atomic<ImageMode> tileMode{};
+  score::gfx::ScaleMode scaleMode{score::gfx::ScaleMode::Original};
+  float scale_w{1.0f};
+  float scale_h{1.0f};
 
 private:
   void process(Message&& msg) override;
