@@ -1,4 +1,5 @@
 #include <Gfx/Graph/RenderedISFNode.hpp>
+#include <Gfx/Graph/RenderedISFSamplerUtils.hpp>
 #include <Gfx/Graph/ShaderCache.hpp>
 
 #include <score/tools/Debug.hpp>
@@ -7,26 +8,10 @@
 namespace score::gfx
 {
 
-
-static void storeTextureRectUniform(char* buffer, int& cur_pos, QSize texSize)
-{
-  while(cur_pos % 16 != 0)
-  {
-    cur_pos += 4;
-  }
-
-  *(float*)(buffer + cur_pos + 0) = 0.0f;
-  *(float*)(buffer + cur_pos + 4) = 0.0f;
-  *(float*)(buffer + cur_pos + 8) = texSize.width();
-  *(float*)(buffer + cur_pos + 12) = texSize.height();
-
-  cur_pos += 16;
-}
-
 RenderedISFNode::~RenderedISFNode() { }
 PassOutput RenderedISFNode::initPassSampler(
-    ISFNode& n, const isf::pass& pass, RenderList& renderer, int& cur_pos,
-    QSize mainTexSize, QRhiResourceUpdateBatch& res)
+    ISFNode& n, const isf::pass& pass, RenderList& renderer, QSize mainTexSize,
+    QRhiResourceUpdateBatch& res)
 {
   QRhi& rhi = *renderer.state.rhi;
   // In all the other cases we create a custom render target
@@ -48,12 +33,6 @@ PassOutput RenderedISFNode::initPassSampler(
   SCORE_ASSERT(tex->create());
   res.uploadTexture(tex, clear_texture);
 
-  if(!pass.target.empty())
-  {
-    // If the target has a name, it has an associated size variable
-    storeTextureRectUniform(n.m_material_data.get(), cur_pos, texSize);
-  }
-
   // Persistent texture means that frame N can access the output of this pass at frame N-1,
   // thus we need two textures, two render targets...
 
@@ -98,96 +77,6 @@ std::vector<Sampler> RenderedISFNode::allSamplers(
   return samplers;
 }
 
-static std::pair<std::vector<Sampler>, int> initInputSamplers(
-    const ProcessNode& node, RenderList& renderer, const std::vector<Port*>& ports,
-    ossia::small_flat_map<const Port*, TextureRenderTarget, 2>& m_rts,
-    char* materialData)
-{
-  std::vector<Sampler> samplers;
-  QRhi& rhi = *renderer.state.rhi;
-  int cur_pos = 0;
-
-  int cur_port = 0;
-  for(Port* in : ports)
-  {
-    switch(in->type)
-    {
-      case Types::Empty:
-        break;
-      case Types::Int:
-      case Types::Float:
-        cur_pos += 4;
-        break;
-      case Types::Vec2:
-        cur_pos += 8;
-        if(cur_pos % 8 != 0)
-          cur_pos += 4;
-        break;
-      case Types::Vec3:
-        while(cur_pos % 16 != 0)
-        {
-          cur_pos += 4;
-        }
-        cur_pos += 12;
-        break;
-      case Types::Vec4:
-        while(cur_pos % 16 != 0)
-        {
-          cur_pos += 4;
-        }
-        cur_pos += 16;
-        break;
-      case Types::Image: {
-        auto spec = node.resolveRenderTargetSpecs(cur_port, renderer);
-        auto sampler = rhi.newSampler(
-            spec.mag_filter, spec.min_filter, spec.mipmap_mode, spec.address_u,
-            spec.address_v, spec.address_w);
-        sampler->setName("ISFNode::initInputSamplers::sampler");
-        SCORE_ASSERT(sampler->create());
-
-        auto rt = score::gfx::createRenderTarget(
-            renderer.state, spec.format, spec.size, renderer.samples(),
-            renderer.requiresDepth());
-        auto texture = rt.texture;
-        samplers.push_back({sampler, texture});
-
-        m_rts[in] = std::move(rt);
-
-        // Allocate some space for the vec4 _imgRect in the uniform
-        storeTextureRectUniform(materialData, cur_pos, spec.size);
-        break;
-      }
-
-      case Types::Audio:
-        storeTextureRectUniform(materialData, cur_pos, QSize{1024, 2});
-        break;
-      default:
-        break;
-    }
-    cur_port++;
-  }
-  return {samplers, cur_pos};
-}
-
-static std::vector<Sampler>
-initAudioTextures(RenderList& renderer, std::list<AudioTexture>& textures)
-{
-  std::vector<Sampler> samplers;
-  QRhi& rhi = *renderer.state.rhi;
-  for(auto& texture : textures)
-  {
-    auto sampler = rhi.newSampler(
-        QRhiSampler::Linear, QRhiSampler::Linear, QRhiSampler::None,
-        QRhiSampler::ClampToEdge, QRhiSampler::ClampToEdge);
-    sampler->setName("ISFNode::initAudioTextures::sampler");
-    sampler->create();
-
-    samplers.push_back({sampler, &renderer.emptyTexture()});
-    texture.samplers[&renderer] = {sampler, nullptr};
-  }
-  return samplers;
-}
-
 RenderedISFNode::RenderedISFNode(const ISFNode& node) noexcept
     : score::gfx::NodeRenderer{node}
     , n{const_cast<ISFNode&>(node)}
@@ -390,8 +279,8 @@ std::pair<Pass, Pass> RenderedISFNode::createPass(
 }
 
 void RenderedISFNode::initPasses(
-    const TextureRenderTarget& rt, RenderList& renderer, Edge& edge, int& cur_pos,
-    QSize mainTexSize, QRhiResourceUpdateBatch& res)
+    const TextureRenderTarget& rt, RenderList& renderer, Edge& edge, QSize mainTexSize,
+    QRhiResourceUpdateBatch& res)
 {
   Passes passes;
 
@@ -409,7 +298,7 @@ void RenderedISFNode::initPasses(
     }
     else
     {
-      auto sampler = initPassSampler(n, pass, renderer, cur_pos, mainTexSize, res);
+      auto sampler = initPassSampler(n, pass, renderer, mainTexSize, res);
       passes.samplers.push_back(sampler);
     }
   }
@@ -507,22 +396,18 @@ void RenderedISFNode::init(RenderList& renderer, QRhiResourceUpdateBatch& res)
   SCORE_ASSERT(m_inputSamplers.empty());
   SCORE_ASSERT(m_audioSamplers.empty());
 
-  auto [samplers, cur_pos]
-      = initInputSamplers(this->n, renderer, n.input, m_rts, n.m_material_data.get());
-  m_inputSamplers = std::move(samplers);
+  m_inputSamplers = initInputSamplers(this->n, renderer, n.input, m_rts);
 
   m_audioSamplers = initAudioTextures(renderer, n.m_audio_textures);
 
   // Create the passes
 
-  int pos_before_passes = cur_pos;
   for(Edge* edge : n.output[0]->edges)
   {
-    cur_pos = pos_before_passes;
     auto rt = renderer.renderTargetForOutput(*edge);
     if(rt.renderTarget)
     {
-      initPasses(rt, renderer, *edge, cur_pos, renderer.renderSize(edge), res);
+      initPasses(rt, renderer, *edge, renderer.renderSize(edge), res);
     }
   }
 }
@@ -617,7 +502,6 @@ void RenderedISFNode::release(RenderList& r)
 {
   // customRelease
   {
-
     for(auto [edge, rt] : m_rts)
     {
       rt.release();
@@ -696,7 +580,6 @@ void RenderedISFNode::release(RenderList& r)
   m_materialUBO = nullptr;
 
   m_meshBuffer = nullptr;
-
 }
 
 void RenderedISFNode::runInitialPasses(
@@ -817,13 +700,17 @@ AudioTextureUpload::AudioTextureUpload()
 void AudioTextureUpload::process(
     AudioTexture& audio, QRhiResourceUpdateBatch& res, QRhiTexture* rhiTexture)
 {
-  if(audio.fft)
+  switch(audio.mode)
   {
-    processSpectral(audio, res, rhiTexture);
-  }
-  else
-  {
-    processTemporal(audio, res, rhiTexture);
+    case AudioTexture::Mode::Waveform:
+      processTemporal(audio, res, rhiTexture);
+      break;
+    case AudioTexture::Mode::FFT:
+      processSpectral(audio, res, rhiTexture);
+      break;
+    case AudioTexture::Mode::Histogram:
+      processHistogram(audio, res, rhiTexture);
+      break;
   }
 }
 
@@ -845,29 +732,107 @@ void AudioTextureUpload::processTemporal(
   res.uploadTexture(rhiTexture, desc);
 }
 
+void AudioTextureUpload::processHistogram(
+    AudioTexture& audio, QRhiResourceUpdateBatch& res, QRhiTexture* rhiTexture)
+{
+  // Size of the audio input buffer
+  std::size_t audioInputBufferSize = audio.data.size() / audio.channels;
+
+  // Effective size of the FFT data we want to use (e.g. without DC offset and nyquist coefficient at the end)
+  std::size_t fftSize = audioInputBufferSize / 2 - 2;
+  m_scratchpad.resize(240 * fftSize);
+  if(m_scratchpad.empty())
+    return;
+
+  // 1. Rotate the scratchpad by one row (fftSize)
+  auto channel_begin = m_scratchpad.begin();
+  std::rotate(channel_begin, m_scratchpad.end() - fftSize, m_scratchpad.end());
+
+  {
+    const float dbmax = 0.f;
+    const float dbmin = -100.f;
+    const float byte_norm = 255.f / (dbmax - dbmin);
+    const float norm = 2.f / (fftSize);
+
+    for(int i = 0; i < 1; i++)
+    {
+      float* inputData = audio.data.data() + i * audioInputBufferSize;
+      double current_window_value = 0.;
+
+      // Basic window function on the audio buffer
+      double window_increment = 1. / (audioInputBufferSize / 2);
+      for(int s = 0; s < audioInputBufferSize / 2; s++)
+      {
+        inputData[s] *= current_window_value;
+        current_window_value += window_increment;
+      }
+      for(int s = audioInputBufferSize / 2; s < audioInputBufferSize; s++)
+      {
+        current_window_value -= window_increment;
+        inputData[s] *= current_window_value;
+      }
+
+      // Compute fft. Spectrum is in CCs format.
+      auto spectrum = m_fft.execute(inputData, audioInputBufferSize);
+
+      float* outputSpectrum = m_scratchpad.data();
+
+      // Compute the actual data to show
+      for(std::size_t k = 1; k < fftSize - 1; k++)
+      {
+        const float float_magnitude
+            = std::sqrt(
+                  spectrum[k][0] * spectrum[k][0] + spectrum[k][1] * spectrum[k][1])
+              * norm;
+        const float float_db = 20.f * std::log10(std ::max(float_magnitude, 1e-10f));
+
+        const float magnitude_byte = (float_db - dbmin) * byte_norm;
+
+        // We are going to put the data in a R32F texture thus we scale to [0; 1]
+        outputSpectrum[k - 1] = std::clamp(magnitude_byte, 0.f, 255.f) / 255.f;
+      }
+    }
+  }
+  // Copy it
+  QRhiTextureSubresourceUploadDescription subdesc(
+      m_scratchpad.data(), m_scratchpad.size() * sizeof(float));
+  QRhiTextureUploadEntry entry{0, 0, subdesc};
+  QRhiTextureUploadDescription desc{entry};
+  res.uploadTexture(rhiTexture, desc);
+}
+
 void AudioTextureUpload::processSpectral(
     AudioTexture& audio, QRhiResourceUpdateBatch& res, QRhiTexture* rhiTexture)
 {
-  if(m_scratchpad.size() < audio.data.size())
-    m_scratchpad.resize(audio.data.size() / 2);
-  std::size_t bufferSize = audio.data.size() / audio.channels;
-  std::size_t fftSize = bufferSize / 2;
-  const float norm = 1. / (2. * bufferSize);
+  std::size_t audioBufferSize = audio.data.size() / audio.channels;
+  std::size_t fftSize = audioBufferSize / 2;
+  std::size_t outputSize = fftSize * audio.channels;
+
+  if(m_scratchpad.size() < outputSize)
+    m_scratchpad.resize(outputSize);
+
+  const float norm = 1. / (2. * audioBufferSize);
   for(int i = 0; i < audio.channels; i++)
   {
-    float* inputData = audio.data.data() + i * bufferSize;
-    auto spectrum = m_fft.execute(inputData, bufferSize);
+    float* inputData = audio.data.data() + i * audioBufferSize;
+    auto spectrum = m_fft.execute(inputData, audioBufferSize);
 
     float* outputSpectrum = m_scratchpad.data() + i * fftSize;
     for(std::size_t k = 0; k < fftSize; k++)
     {
-      outputSpectrum[k] = 0.5f + spectrum[k][0] * norm;
+      outputSpectrum[k]
+          = 1.
+            * std::sqrt(
+                spectrum[k][0] * spectrum[k][0] + spectrum[k][1] * spectrum[k][1])
+            * norm;
     }
   }
 
   // Copy it
   QRhiTextureSubresourceUploadDescription subdesc(
-      m_scratchpad.data(), (audio.data.size() / 2) * sizeof(float));
+      m_scratchpad.data(), m_scratchpad.size() * sizeof(float));
+  subdesc.setSourceSize(QSize(fftSize, audio.channels));
+
   QRhiTextureUploadEntry entry{0, 0, subdesc};
   QRhiTextureUploadDescription desc{entry};
   res.uploadTexture(rhiTexture, desc);
@@ -881,53 +846,78 @@ std::optional<Sampler> AudioTextureUpload::updateAudioTexture(
   bool textureChanged = false;
   auto it = audio.samplers.find(&renderer);
   if(it == audio.samplers.end())
+  {
     return {};
+  }
 
   auto& [rhiSampler, rhiTexture] = it->second;
   const auto curSz = (rhiTexture) ? rhiTexture->pixelSize() : QSize{};
   int numSamples = curSz.width() * curSz.height();
-  if(numSamples != int(audio.data.size()))
-  {
-    delete rhiTexture;
-    rhiTexture = nullptr;
-    textureChanged = true;
-  }
-
-  if(!rhiTexture)
+  if(numSamples != std::max(1, int(audio.data.size())) || !rhiTexture)
   {
     if(audio.channels > 0)
     {
       int samples = audio.data.size() / audio.channels;
       if(samples % 2 != 0)
         samples++;
-      int pixelWidth = samples / (audio.fft ? 2 : 1);
-
-      float* rectUniform
-          = reinterpret_cast<float*>(materialData + audio.rectUniformOffset);
-      rectUniform[0] = 0.f;
-      rectUniform[1] = 0.f;
-      rectUniform[2] = pixelWidth;
-      rectUniform[3] = audio.channels;
+      int pixelWidth = 0;
+      int pixelHeight = 0;
+      switch(audio.mode)
+      {
+        case AudioTexture::Mode::Waveform:
+          pixelWidth = samples;
+          pixelHeight = audio.channels;
+          break;
+        case AudioTexture::Mode::FFT:
+          pixelWidth = samples / 2;
+          pixelHeight = audio.channels;
+          break;
+        case AudioTexture::Mode::Histogram:
+          pixelWidth = samples / 2 - 2;
+          pixelHeight = 240;
+          break;
+      }
 
       m_fft.reset(samples);
 
-      rhiTexture = rhi.newTexture(
-          QRhiTexture::R32F, {pixelWidth, audio.channels}, 1, QRhiTexture::Flag{});
-      rhiTexture->setName("AudioTextureUpload::rhiTexture");
-      rhiTexture->create();
-      textureChanged = true;
+      if(rhiTexture)
+      {
+        rhiTexture->destroy();
+        rhiTexture->setPixelSize({pixelWidth, pixelHeight});
+        rhiTexture->create();
+      }
+      else
+      {
+        rhiTexture = rhi.newTexture(
+            QRhiTexture::R32F, {pixelWidth, pixelHeight}, 1, QRhiTexture::Flag{});
+        rhiTexture->setName("AudioTextureUpload::rhiTexture");
+        auto created = rhiTexture->create();
+        SCORE_ASSERT(created);
+        textureChanged = true;
+      }
     }
     else
     {
-      rhiTexture = nullptr;
-      textureChanged = true;
+      if(rhiTexture)
+      {
+        rhiTexture->destroy();
+        rhiTexture->setPixelSize({1, 1});
+        rhiTexture->create();
+      }
+      else
+      {
+        rhiTexture = &renderer.emptyTexture();
+        textureChanged = true;
+      }
     }
   }
 
   if(rhiTexture)
   {
     // Process the audio data
-    this->process(audio, res, rhiTexture);
+    auto sz = rhiTexture->pixelSize();
+    if(sz.width() * sz.height() > 1)
+      this->process(audio, res, rhiTexture);
   }
 
   if(textureChanged)
@@ -941,254 +931,3 @@ std::optional<Sampler> AudioTextureUpload::updateAudioTexture(
 }
 
 }
-
-namespace score::gfx
-{
-
-SimpleRenderedISFNode::SimpleRenderedISFNode(const ISFNode& node) noexcept
-    : score::gfx::NodeRenderer{node}
-    , n{const_cast<ISFNode&>(node)}
-{
-}
-
-TextureRenderTarget SimpleRenderedISFNode::renderTargetForInput(const Port& p)
-{
-  SCORE_ASSERT(m_rts.find(&p) != m_rts.end());
-  return m_rts[&p];
-}
-
-std::vector<Sampler> SimpleRenderedISFNode::allSamplers() const noexcept
-{
-  // Input ports
-  std::vector<Sampler> samplers = m_inputSamplers;
-
-  // Audio textures
-  samplers.insert(samplers.end(), m_audioSamplers.begin(), m_audioSamplers.end());
-
-  return samplers;
-}
-
-void SimpleRenderedISFNode::initPass(
-    const TextureRenderTarget& renderTarget, RenderList& renderer, Edge& edge)
-{
-  auto& model_passes = n.descriptor().passes;
-  SCORE_ASSERT(model_passes.size() == 1);
-
-  QRhi& rhi = *renderer.state.rhi;
-
-  QRhiBuffer* pubo{};
-  pubo = rhi.newBuffer(
-      QRhiBuffer::Dynamic, QRhiBuffer::UniformBuffer, sizeof(ProcessUBO));
-  pubo->setName("SimpleRenderedISFNode::initPass::pubo");
-  pubo->create();
-
-  // Create the main pass
-  try
-  {
-    auto [v, s] = score::gfx::makeShaders(renderer.state, n.m_vertexS, n.m_fragmentS);
-    auto pip = score::gfx::buildPipeline(
-        renderer, *m_mesh, v, s, renderTarget, pubo, m_materialUBO, allSamplers());
-    if(pip.pipeline)
-      m_passes.emplace_back(&edge, Pass{renderTarget, pip, pubo});
-    else
-      delete pubo;
-  }
-  catch(...)
-  {
-  }
-}
-
-void SimpleRenderedISFNode::init(RenderList& renderer, QRhiResourceUpdateBatch& res)
-{
-  QRhi& rhi = *renderer.state.rhi;
-
-  // Create the mesh
-  {
-    m_mesh = this->n.descriptor().default_vertex_shader ? &renderer.defaultTriangle()
-                                                        : &renderer.defaultQuad();
-
-    if(!m_meshBuffer)
-    {
-      auto [mbuffer, ibuffer] = renderer.initMeshBuffer(*m_mesh, res);
-      m_meshBuffer = mbuffer;
-      m_idxBuffer = ibuffer;
-    }
-  }
-
-  // Create the material UBO
-  m_materialSize = n.m_materialSize;
-  if(m_materialSize > 0)
-  {
-    m_materialUBO
-        = rhi.newBuffer(QRhiBuffer::Dynamic, QRhiBuffer::UniformBuffer, m_materialSize);
-    m_materialUBO->setName("SimpleRenderedISFNode::init::m_materialUBO");
-    SCORE_ASSERT(m_materialUBO->create());
-  }
-
-  // Create the samplers
-  SCORE_ASSERT(m_rts.empty());
-  SCORE_ASSERT(m_passes.empty());
-  SCORE_ASSERT(m_inputSamplers.empty());
-  SCORE_ASSERT(m_audioSamplers.empty());
-
-  auto [samplers, cur_pos]
-      = initInputSamplers(this->n, renderer, n.input, m_rts, n.m_material_data.get());
-  m_inputSamplers = std::move(samplers);
-
-  m_audioSamplers = initAudioTextures(renderer, n.m_audio_textures);
-
-  // Create the passes
-
-  for(Edge* edge : n.output[0]->edges)
-  {
-    auto rt = renderer.renderTargetForOutput(*edge);
-    if(rt.renderTarget)
-    {
-      initPass(rt, renderer, *edge);
-    }
-  }
-}
-
-void SimpleRenderedISFNode::update(
-    RenderList& renderer, QRhiResourceUpdateBatch& res, Edge* edge)
-{
-  n.standardUBO.passIndex = 0;
-  n.standardUBO.frameIndex++;
-  auto sz = renderer.renderSize(edge);
-  n.standardUBO.renderSize[0] = sz.width();
-  n.standardUBO.renderSize[1] = sz.height();
-
-  // Update audio textures
-  if(!n.m_audio_textures.empty() && !m_audioTex)
-  {
-    m_audioTex.emplace();
-  }
-
-  bool audioChanged = false;
-  for(auto& audio : n.m_audio_textures)
-  {
-    if(std::optional<Sampler> sampl
-       = m_audioTex->updateAudioTexture(audio, renderer, n.m_material_data.get(), res))
-    {
-      // Texture changed -> material changed
-      audioChanged = true;
-
-      auto& [rhiSampler, tex] = *sampl;
-      for(auto& [e, pass] : m_passes)
-      {
-        score::gfx::replaceTexture(
-            *pass.p.srb, rhiSampler, tex ? tex : &renderer.emptyTexture());
-      }
-    }
-  }
-
-  // Update material
-  if(m_materialUBO && m_materialSize > 0 && (materialChanged || audioChanged))
-  {
-    char* data = n.m_material_data.get();
-    res.updateDynamicBuffer(m_materialUBO, 0, m_materialSize, data);
-  }
-
-  // Update all the process UBOs
-  for(auto& [e, pass] : m_passes)
-  {
-    res.updateDynamicBuffer(
-        pass.processUBO, 0, sizeof(ProcessUBO), &this->n.standardUBO);
-  }
-}
-
-void SimpleRenderedISFNode::release(RenderList& r)
-{
-  // customRelease
-  {
-    for(auto [edge, rt] : m_rts)
-    {
-      rt.release();
-    }
-    m_rts.clear();
-
-    for(auto& texture : n.m_audio_textures)
-    {
-      auto it = texture.samplers.find(&r);
-      if(it != texture.samplers.end())
-      {
-        if(auto tex = it->second.texture)
-        {
-          if(tex != &r.emptyTexture())
-            tex->deleteLater();
-        }
-      }
-    }
-
-    for(auto& [edge, pass] : m_passes)
-    {
-      pass.p.release();
-
-      if(pass.processUBO)
-        pass.processUBO->deleteLater();
-    }
-
-    m_passes.clear();
-  }
-
-  for(auto sampler : m_inputSamplers)
-  {
-    delete sampler.sampler;
-    // texture isdeleted elsewxheree
-  }
-  m_inputSamplers.clear();
-  for(auto sampler : m_audioSamplers)
-  {
-    delete sampler.sampler;
-    // texture isdeleted elsewxheree
-  }
-  m_audioSamplers.clear();
-
-  delete m_materialUBO;
-  m_materialUBO = nullptr;
-
-  m_meshBuffer = nullptr;
-}
-
-void SimpleRenderedISFNode::runInitialPasses(
-    RenderList& renderer, QRhiCommandBuffer& cb, QRhiResourceUpdateBatch*& updateBatch,
-    Edge& edge)
-{
-}
-
-void SimpleRenderedISFNode::runRenderPass(
-    RenderList& renderer, QRhiCommandBuffer& cb, Edge& edge)
-{
-  auto it = ossia::find_if(this->m_passes, [&](auto& p) { return p.first == &edge; });
-  // Maybe the shader could not be created
-  if(it == this->m_passes.end())
-    return;
-
-  auto& pass = it->second;
-
-  // Draw the last pass
-  {
-    SCORE_ASSERT(pass.renderTarget.renderTarget);
-    SCORE_ASSERT(pass.p.pipeline);
-    SCORE_ASSERT(pass.p.srb);
-    // TODO : combine all the uniforms..
-
-    auto pipeline = pass.p.pipeline;
-    auto srb = pass.p.srb;
-    auto texture = pass.renderTarget.texture;
-
-    // TODO need to free stuff
-    {
-      cb.setGraphicsPipeline(pipeline);
-      cb.setShaderResources(srb);
-      cb.setViewport(QRhiViewport(
-          0, 0, texture->pixelSize().width(), texture->pixelSize().height()));
-
-      m_mesh->draw({this->m_meshBuffer, this->m_idxBuffer}, cb);
-    }
-  }
-}
-
-SimpleRenderedISFNode::~SimpleRenderedISFNode() { }
-
-}
