@@ -37,8 +37,12 @@ struct AudioTexture
   std::vector<float> data;
   int channels{};
   int fixedSize{0};
-  int rectUniformOffset{};
-  bool fft{};
+  enum Mode
+  {
+    Waveform,
+    FFT,
+    Histogram
+  } mode{};
 };
 
 /**
