@@ -71,6 +71,7 @@ Gfx::Settings::GraphicsApis::operator QStringList() const noexcept
 #endif
 
 #if defined(Q_OS_MACOS) || defined(Q_OS_IOS)
+  // https://github.com/ossia/score/issues/1807
   lst += Metal;
 #endif
   return lst;
@@ -99,10 +100,10 @@ Gfx::Settings::HardwareVideoDecoder::operator QStringList() const noexcept
     lst += V4L2;
 #endif
 
-  if(auto c = avcodec_find_decoder_by_name("h264_vdpau"))
+  if(avcodec_find_decoder_by_name("h264_vdpau"))
     lst += VDPAU;
 
-  if(auto c = avcodec_find_decoder_by_name("mjpeg_vaapi"))
+  if(avcodec_find_decoder_by_name("mjpeg_vaapi"))
     lst += VAAPI;
 #endif
 
@@ -132,6 +133,11 @@ score::gfx::GraphicsApi Model::graphicsApiEnum() const noexcept
   else if(platform == "vkkhrdisplay")
     return score::gfx::Vulkan;
 
+  // https://github.com/ossia/score/issues/1807
+#if defined(Q_OS_MACOS) || defined(Q_OS_IOS)
+  return score::gfx::Metal;
+#endif
+
   if(m_GraphicsApi == apis.Vulkan)
   {
     return score::gfx::Vulkan;
