@@ -18,6 +18,14 @@
 
 namespace Gfx::Spout
 {
+class InputSettingsWidget final : public SharedInputSettingsWidget
+{
+public:
+  explicit InputSettingsWidget(QWidget* parent = nullptr);
+
+  Device::DeviceSettings getSettings() const override;
+};
+
 struct SpoutInputNode : score::gfx::ProcessNode
 {
 public:
@@ -249,6 +257,14 @@ public:
   ~InputDevice() { }
 
 private:
+  void disconnect() override
+  {
+    Gfx::GfxInputDevice::disconnect();
+    auto prev = std::move(m_dev);
+    m_dev = {};
+    deviceChanged(prev.get(), nullptr);
+  }
+
   bool reconnect() override
   {
     disconnect();
@@ -265,6 +281,7 @@ private:
         m_dev = std::make_unique<simple_texture_input_device>(
             new SpoutInputNode{set}, &plug->exec, std::move(protocol),
             this->settings().name.toStdString());
+        deviceChanged(nullptr, m_dev.get());
       }
     }
     catch(std::exception& e)
