@@ -50,6 +50,7 @@ public:
     m_screen->onMouseMove = [](QPointF, QPointF) {};
     m_screen->onTabletMove = [](QTabletEvent*) {};
     m_screen->onKey = [](int, const QString&) {};
+    m_screen->onKeyRelease = [](int, const QString&) { };
     m_protocol->stop();
 
     m_root.clear_children();
@@ -100,24 +101,34 @@ public:
     }
 
     {
+      struct move_window_lock
+      {
+        bool locked{};
+      };
+      auto lock = std::make_shared<move_window_lock>();
+
       auto pos_node
           = std::make_unique<ossia::net::generic_node>("position", *this, m_root);
       auto pos_param = pos_node->create_parameter(ossia::val_type::VEC2F);
-      pos_param->add_callback([this](const ossia::value& v) {
+      pos_param->add_callback([this, lock](const ossia::value& v) {
+        if(lock->locked)
+          return;
         if(auto val = v.target<ossia::vec2f>())
         {
-          ossia::qt::run_async(&m_qtContext, [screen = this->m_screen, v = *val] {
+          ossia::qt::run_async(&m_qtContext, [screen = this->m_screen, v = *val, lock] {
             screen->setPosition({(int)v[0], (int)v[1]});
           });
         }
       });
 
-      m_screen->onWindowMove = [this, pos_param](QPointF pos) {
+      m_screen->onWindowMove = [this, pos_param, lock](QPointF pos) {
+        if(lock->locked)
+          return;
         if(const auto& w = m_screen->window())
         {
-          auto geom = w->geometry();
-          pos_param->set_value(
-              ossia::vec2f{float(pos.x()), float(pos.y())});
+          lock->locked = true;
+          pos_param->set_value(ossia::vec2f{float(pos.x()), float(pos.y())});
+          lock->locked = false;
         }
       };
       m_root.add_child(std::move(pos_node));
@@ -317,26 +328,57 @@ public:
     // Keyboard input
     {
       auto node = std::make_unique<ossia::net::generic_node>("key", *this, m_root);
-      ossia::net::parameter_base* press_param{};
-      ossia::net::parameter_base* text_param{};
       {
         auto press_node
-            = std::make_unique<ossia::net::generic_node>("code", *this, *node);
-        press_param = press_node->create_parameter(ossia::val_type::INT);
-        press_param->push_value(ossia::vec2f{0.f, 0.f});
+            = std::make_unique<ossia::net::generic_node>("press", *this, *node);
+        ossia::net::parameter_base* press_param{};
+        ossia::net::parameter_base* text_param{};
+        {
+          auto code_node
+              = std::make_unique<ossia::net::generic_node>("code", *this, *press_node);
+          press_param = code_node->create_parameter(ossia::val_type::INT);
+          press_param->push_value(ossia::vec2f{0.f, 0.f});
+          press_node->add_child(std::move(code_node));
+        }
+        {
+          auto text_node
+              = std::make_unique<ossia::net::generic_node>("text", *this, *press_node);
+          text_param = text_node->create_parameter(ossia::val_type::STRING);
+          press_node->add_child(std::move(text_node));
+        }
+
+        m_screen->onKey = [press_param, text_param](int key, const QString& text) {
+          press_param->push_value(key);
+          text_param->push_value(text.toStdString());
+        };
         node->add_child(std::move(press_node));
       }
       {
-        auto text_node
-            = std::make_unique<ossia::net::generic_node>("text", *this, *node);
-        text_param = text_node->create_parameter(ossia::val_type::STRING);
-        node->add_child(std::move(text_node));
-      }
+        auto release_node
+            = std::make_unique<ossia::net::generic_node>("release", *this, *node);
+        ossia::net::parameter_base* press_param{};
+        ossia::net::parameter_base* text_param{};
+        {
+          auto code_node
+              = std::make_unique<ossia::net::generic_node>("code", *this, *release_node);
+          press_param = code_node->create_parameter(ossia::val_type::INT);
+          press_param->push_value(ossia::vec2f{0.f, 0.f});
+          release_node->add_child(std::move(code_node));
+        }
+        {
+          auto text_node
+              = std::make_unique<ossia::net::generic_node>("text", *this, *release_node);
+          text_param = text_node->create_parameter(ossia::val_type::STRING);
+          release_node->add_child(std::move(text_node));
+        }
 
-      m_screen->onKey = [press_param, text_param](int key, const QString& text) {
-        press_param->push_value(key);
-        text_param->push_value(text.toStdString());
-      };
+        m_screen->onKeyRelease
+            = [press_param, text_param](int key, const QString& text) {
+          press_param->push_value(key);
+          text_param->push_value(text.toStdString());
+        };
+        node->add_child(std::move(release_node));
+      }
 
       m_root.add_child(std::move(node));
     }
@@ -403,7 +445,9 @@ void WindowDevice::setupContextMenu(QMenu& menu) const
 void WindowDevice::disconnect()
 {
   DeviceInterface::disconnect();
+  auto prev = std::move(m_dev);
   m_dev = {};
+  deviceChanged(prev.get(), nullptr);
 }
 
 bool WindowDevice::reconnect()
@@ -420,6 +464,7 @@ bool WindowDevice::reconnect()
           std::unique_ptr<gfx_protocol_base>(m_protocol), m_settings.name.toStdString());
 
       enableCallbacks();
+      deviceChanged(nullptr, m_dev.get());
     }
     // TODOengine->reload(&proto);
 
