@@ -5,6 +5,7 @@
 #include <Gfx/Graph/NodeRenderer.hpp>
 #include <Gfx/Graph/RenderList.hpp>
 #include <Gfx/Graph/RenderState.hpp>
+#include <Gfx/Graph/Window.hpp>
 #include <JS/Qml/QmlObjects.hpp>
 
 #include <ossia-qt/js_utilities.hpp>
@@ -255,6 +256,9 @@ void main()
 {
   v_texcoord = texcoord;
   gl_Position = renderer.clipSpaceCorrMatrix * vec4(position, 0.0, 1.);
+#if defined(QSHADER_GLSL) || defined(QSHADER_HLSL) || defined(QSHADER_MSL)
+  gl_Position.y = - gl_Position.y;
+#endif
 }
 )_";
 
@@ -271,7 +275,7 @@ layout(location = 0) out vec4 fragColor;
 
 void main ()
 {
-  fragColor = texture(y_tex, vec2(v_texcoord.x, 1. - v_texcoord.y));
+  fragColor = texture(y_tex, vec2(v_texcoord.x, v_texcoord.y));
 }
 )_";
 
@@ -287,8 +291,8 @@ void main ()
 
     // Init the texture on which we are going to render
     m_internalTex = score::gfx::createRenderTarget(
-        renderer.state, QRhiTexture::RGBA32F, renderer.state.renderSize,
-        renderer.state.samples);
+        renderer.state, QRhiTexture::RGBA8, renderer.state.renderSize,
+        renderer.state.samples, renderer.requiresDepth());
 
     // Init basic rendering ubos
     const auto& mesh = renderer.defaultQuad();
@@ -314,10 +318,22 @@ void main ()
     // Init the QQuick render stuff
     m_renderControl = new QQuickRenderControl{};
     m_window = new QQuickWindow{m_renderControl};
+    if(auto win = renderer.state.window.lock())
+    {
+      QObject::connect(
+          win.get(), &score::gfx::Window::interactiveEvent, m_window,
+          [qqw = QPointer{m_window}](QEvent* e) {
+        if(auto q = qqw.get())
+          QCoreApplication::sendEvent(q, e);
+      }, Qt::DirectConnection);
+    }
     m_window->setGraphicsDevice(QQuickGraphicsDevice::fromRhi(&rhi));
 
-    m_window->setWidth(renderer.state.renderSize.width());
-    m_window->setHeight(renderer.state.renderSize.height());
+    const auto sz = renderer.state.renderSize;
+    m_window->setWidth(sz.width());
+    m_window->setHeight(sz.height());
+    m_window->contentItem()->setWidth(sz.width());
+    m_window->contentItem()->setWidth(sz.height());
     m_window->setColor(Qt::transparent);
 
     m_renderControl->initialize();
@@ -349,7 +365,10 @@ void main ()
     }
   }
 
-  void update(score::gfx::RenderList& renderer, QRhiResourceUpdateBatch& res) override {
+  void update(
+      score::gfx::RenderList& renderer, QRhiResourceUpdateBatch& res,
+      score::gfx::Edge* edge) override
+  {
     reloadEngine(renderer.state.rhi);
     defaultUBOUpdate(renderer, res);
   }
@@ -369,6 +388,10 @@ void main ()
       QRhiResourceUpdateBatch*& res, score::gfx::Edge& e) override
   {
     // Here we run the Qt Qucik render loop which handles its own pass
+    if(auto sz = m_window->size(); sz != m_window->contentItem()->size())
+    {
+      m_window->contentItem()->setSize(sz); // why does this happen???
+    }
 
     // 0. Copy the values in the inputs
     processMessages();
@@ -400,8 +423,6 @@ void main ()
 
     auto rt = renderer.renderTargetForOutput(e).renderTarget;
     SCORE_ASSERT(rt);
-    cb.beginPass(rt, QColor(Qt::transparent), {}, res);
-    res = nullptr;
 
     cd->syncSceneGraph();
     rc->rc->endSync();
@@ -419,8 +440,6 @@ void main ()
 
     QEvent* updateRequest = new QEvent(QEvent::UpdateRequest);
     QCoreApplication::postEvent(m_window, updateRequest);
-    // cb.endPass(); // < called by renderSceneGraph
-    res = renderer.state.rhi->nextResourceUpdateBatch();
   }
 
   void runRenderPass(
