@@ -132,12 +132,24 @@ public:
   int outlets(QObject* obj);
   W_SLOT(outlets)
 
+  QObject* createCable(QObject* outlet, QObject* inlet);
+  W_SLOT(createCable)
+
   void setAddress(QObject* obj, QString addr);
   W_SLOT(setAddress)
 
   void setValue(QObject* obj, double value);
   W_SLOT(setValue, (QObject*, double))
 
+  void setValue(QObject* obj, QVector2D value);
+  W_SLOT(setValue, (QObject*, QVector2D))
+
+  void setValue(QObject* obj, QVector3D value);
+  W_SLOT(setValue, (QObject*, QVector3D))
+
+  void setValue(QObject* obj, QVector4D value);
+  W_SLOT(setValue, (QObject*, QVector4D))
+
   void setValue(QObject* obj, QString value);
   W_SLOT(setValue, (QObject*, QString))
 
@@ -284,9 +296,13 @@ public:
   /////////////////////
   QVariant availableProcesses() const noexcept;
   W_SLOT(availableProcesses)
+  QVariant availableProcessesAndPresets() const noexcept;
+  W_SLOT(availableProcessesAndPresets)
   QVariant availableProtocols() const noexcept;
   W_SLOT(availableProtocols)
 
+  QByteArray serializeAsJson() noexcept;
+  W_SLOT(serializeAsJson)
 private:
   void submit(Macro& m, score::Command* c);
 };
