@@ -1,6 +1,7 @@
 #include <Media/Effect/Settings/Model.hpp>
 
 #include <QDir>
+#include <QStandardPaths>
 namespace Media::Settings
 {
 namespace Parameters
@@ -8,16 +9,18 @@ namespace Parameters
 
 SETTINGS_PARAMETER_IMPL(VstPaths){
     QStringLiteral("Effect/VstPaths"),
-    {(QString::fromUtf8(qgetenv("HOME")) + QDir::separator() + ".vst"),
+    {(QStandardPaths::writableLocation(QStandardPaths::HomeLocation) + QDir::separator()
+      + ".vst"),
 #if defined(__APPLE__)
      "/Library/Audio/Plug-Ins/VST"
 #elif defined(__linux__)
      QStringLiteral("/usr/lib/vst"), QStringLiteral("/usr/lib/lxvst"),
      QStringLiteral("/usr/lib64/vst"), QStringLiteral("/usr/lib64/lxvst")
 #elif defined(_WIN32)
-     "C:\\Program Files\\VSTPlugins", "C:\\Program Files\\Steinberg\\VSTPlugins",
-     "C:\\Program Files\\Common Files\\VST2",
-     "C:\\Program Files\\Common Files\\Steinberg\\VST2"
+     QStringLiteral("C:\\Program Files\\VSTPlugins"),
+     QStringLiteral("C:\\Program Files\\Steinberg\\VSTPlugins"),
+     QStringLiteral("C:\\Program Files\\Common Files\\VST2"),
+     QStringLiteral("C:\\Program Files\\Common Files\\Steinberg\\VST2")
 #else
 
      "/usr/lib/vst"
