@@ -3,6 +3,7 @@
 #if defined(OSSIA_PROTOCOL_ARTNET)
 #include <score/tools/std/StringHash.hpp>
 
+#include <ossia/detail/nullable_variant.hpp>
 #include <ossia/detail/variant.hpp>
 
 #include <QString>
@@ -31,8 +32,57 @@ struct RangeCapability : BaseCapability
   std::pair<int, int> range;
 };
 
+enum class Diode : int8_t
+{
+  R,
+  G,
+  B,
+  White,
+  WarmWhite,
+  ColdWhite,
+  Amber,
+  UV,
+  CCT,
+  Empty
+};
+
+struct LEDStripLayout
+{
+  std::vector<Diode> diodes;
+
+  int length{}; // in pixels
+  bool reverse{};
+
+  int channels() const noexcept { return diodes.size() * length; }
+};
+
+struct LEDPaneLayout
+{
+  std::vector<Diode> diodes;
+
+  int width{};
+  int height{};
+
+  int channels() const noexcept { return diodes.size() * width * height; }
+};
+
+struct LEDVolumeLayout
+{
+  std::vector<Diode> diodes;
+
+  int width{};
+  int height{};
+  int depth{};
+
+  int channels() const noexcept { return diodes.size() * width * height * depth; }
+};
+
 using FixtureCapabilities
     = ossia::variant<SingleCapability, std::vector<RangeCapability>>;
+
+using LEDLayout
+    = ossia::nullable_variant<LEDStripLayout, LEDPaneLayout, LEDVolumeLayout>;
+
 struct Channel
 {
   QString name;
@@ -52,17 +102,23 @@ struct Fixture
   QString modeName;
   ModeInfo mode;
   std::vector<Channel> controls;
+  LEDLayout led;
   int address{};
+  int universe{};
 };
-
 }
 
 struct ArtnetSpecificSettings
 {
   std::vector<Artnet::Fixture> fixtures;
+
   QString host;
-  int rate{20};
-  int universe{1};
+  int rate{44};
+  int start_universe{0};
+  int universe_count{1};
+  int channels_per_universe{512};
+  bool multicast{};
+
   enum
   {
     ArtNet, // Artnet:/Channel-{}
@@ -70,6 +126,7 @@ struct ArtnetSpecificSettings
     DMXUSBPRO,
     ArtNetV2, // Artnet:/{}
     DMXUSBPRO_Mk2,
+    OpenDMX_USB
   } transport{ArtNetV2};
   enum
   {
