@@ -4,6 +4,7 @@
 
 #include <Dataflow/Commands/CableHelpers.hpp>
 
+#include <score/command/AggregateCommand.hpp>
 #include <score/command/Command.hpp>
 #include <score/model/Identifier.hpp>
 #include <score/model/path/Path.hpp>
@@ -44,5 +45,11 @@ private:
   Rack m_smallView;
   bool m_smallViewVisible{};
 };
+
+class RemoveProcessAndKeepLinked final : public score::AggregateCommand
+{
+  SCORE_COMMAND_DECL(
+      CommandFactoryName(), RemoveProcessAndKeepLinked, "Remove process from chain")
+};
 }
 }
