@@ -1,5 +1,13 @@
 #pragma once
 
+#include <Process/TimeValue.hpp>
+
+#include <functional>
+
+namespace score
+{
+struct Dispatcher;
+}
 namespace Process
 {
 class Cable;
@@ -7,33 +15,38 @@ class Inlet;
 class Outlet;
 class ProcessModel;
 struct Preset;
-}
-
-namespace Library
-{
+struct Context;
 struct ProcessData;
 }
 
 namespace Scenario
 {
+class ScenarioDocumentModel;
 class ScenarioDocumentPresenter;
 
 void createProcessInCable(
-    Scenario::ScenarioDocumentPresenter& parent, const Library::ProcessData& dat,
-    const Process::Cable& cbl);
-void loadPresetInCable(
-    Scenario::ScenarioDocumentPresenter& parent, const Process::Preset& dat,
+    const Process::Context& context, const Scenario::ScenarioDocumentModel& model,
+    const Process::ProcessData& dat, std::optional<TimeVal>,
+    std::function<void(Process::ProcessModel&, score::Dispatcher&)>,
     const Process::Cable& cbl);
 
+void loadPresetInCable(
+    const Process::Context& context, const Scenario::ScenarioDocumentModel& model,
+    const Process::Preset& dat, const Process::Cable& cbl);
+
 void createProcessBeforePort(
-    Scenario::ScenarioDocumentPresenter& parent, const Library::ProcessData& dat,
+    Scenario::ScenarioDocumentPresenter& parent, const Process::ProcessData& dat,
+    std::optional<TimeVal>,
+    std::function<void(Process::ProcessModel&, score::Dispatcher&)>,
     const Process::ProcessModel& parentProcess, const Process::Inlet& p);
 void loadPresetBeforePort(
     Scenario::ScenarioDocumentPresenter& parent, const Process::Preset& dat,
     const Process::ProcessModel& parentProcess, const Process::Inlet& p);
 
 void createProcessAfterPort(
-    Scenario::ScenarioDocumentPresenter& parent, const Library::ProcessData& dat,
+    Scenario::ScenarioDocumentPresenter& parent, const Process::ProcessData& dat,
+    std::optional<TimeVal>,
+    std::function<void(Process::ProcessModel&, score::Dispatcher&)>,
     const Process::ProcessModel& parentProcess, const Process::Outlet& p);
 void loadPresetAfterPort(
     Scenario::ScenarioDocumentPresenter& parent, const Process::Preset& dat,
