@@ -1,5 +1,7 @@
 #include "ScenarioEditor.hpp"
 
+#include <Process/Commands/EditPort.hpp>
+
 #include <Scenario/Application/Drops/DropLayerInInterval.hpp>
 #include <Scenario/Application/Menus/ScenarioCopy.hpp>
 #include <Scenario/Application/ScenarioActions.hpp>
@@ -314,11 +316,10 @@ bool ScenarioEditor::remove(const Selection& s, const score::DocumentContext& ct
 {
   if(s.size() == 1)
   {
-    CommandDispatcher<> d{ctx.commandStack};
-
     auto first = s.begin()->data();
     if(auto c = qobject_cast<const Process::Cable*>(first))
     {
+      CommandDispatcher<> d{ctx.commandStack};
       auto& doc = score::IDocument::get<ScenarioDocumentModel>(ctx.document);
       d.submit<Dataflow::RemoveCable>(doc, *c);
       return true;
@@ -329,11 +330,100 @@ bool ScenarioEditor::remove(const Selection& s, const score::DocumentContext& ct
       auto p = proc->parent();
       if(auto itv = qobject_cast<IntervalModel*>(p))
       {
-        d.submit<RemoveProcessFromInterval>(*itv, proc->id());
-        return true;
+        auto& doc = score::IDocument::get<ScenarioDocumentModel>(ctx.document);
+        if(qApp->keyboardModifiers() & Qt::ShiftModifier)
+        {
+          // 1. Is the process part of a chain
+          auto& is = proc->inlets();
+          auto& os = proc->outlets();
+          if(is.empty() || os.empty() || is[0]->type() != os[0]->type())
+          {
+            // Not a mapping, we don't copy anything
+            CommandDispatcher<> d{ctx.commandStack};
+            d.submit<RemoveProcessFromInterval>(*itv, proc->id());
+            return true;
+          }
+          else
+          {
+            Scenario::Command::Macro m{
+                new Scenario::Command::RemoveProcessAndKeepLinked, ctx};
+
+            const int inbound_cables = !is[0]->cables().empty();
+            const int outbound_cables = !os[0]->cables().empty();
+
+            if(inbound_cables && outbound_cables)
+            {
+              // Copy the cables
+              for(auto& in_cbl : is[0]->cables())
+              {
+                auto& src = in_cbl.find(ctx).source().find(ctx);
+                for(auto& out_cbl : os[0]->cables())
+                {
+                  auto& sink = out_cbl.find(ctx).sink().find(ctx);
+                  m.createCable(doc, src, sink);
+                }
+              }
+            }
+            else if(inbound_cables && !outbound_cables)
+            {
+              if(os[0]->address().isSet())
+              {
+                // Copy out address to previous inputs
+                auto& addr = os[0]->address();
+                for(auto& in_cbl : is[0]->cables())
+                {
+                  auto& src = in_cbl.find(ctx).source().find(ctx);
+                  m.setProperty<Process::Port::p_address>(src, addr);
+                }
+              }
+              if(os[0]->type() == Process::PortType::Audio)
+              {
+                bool end_propagate
+                    = static_cast<Process::AudioOutlet*>(os[0])->propagate();
+                if(end_propagate)
+                  for(auto& in_cbl : is[0]->cables())
+                  {
+                    auto& src = in_cbl.find(ctx).source().find(ctx);
+                    auto& audio_src = *static_cast<Process::AudioOutlet*>(&src);
+                    m.setProperty<Process::AudioOutlet::p_propagate>(
+                        audio_src, end_propagate);
+                  }
+              }
+            }
+            else if(!inbound_cables && outbound_cables)
+            {
+              if(is[0]->address().isSet())
+              {
+                // Copy in address to next outputs
+                auto& addr = is[0]->address();
+                for(auto& out_cbl : os[0]->cables())
+                {
+                  auto& src = out_cbl.find(ctx).sink().find(ctx);
+                  m.setProperty<Process::Port::p_address>(src, addr);
+                }
+              }
+            }
+            else if(!inbound_cables && !outbound_cables)
+            {
+              // nothing to do
+            }
+
+            // Remove the process
+            m.removeProcess(*itv, proc->id());
+            m.commit();
+          }
+          return true;
+        }
+        else
+        {
+          CommandDispatcher<> d{ctx.commandStack};
+          d.submit<RemoveProcessFromInterval>(*itv, proc->id());
+          return true;
+        }
       }
       else if(auto st = qobject_cast<StateModel*>(p))
       {
+        CommandDispatcher<> d{ctx.commandStack};
         d.submit<RemoveStateProcess>(*st, proc->id());
         return true;
       }
